interface NotificationConfig {
    /**
     * Event ID.
     * @format GUID
     * @immutable
     */
    _id?: string | null;
    /**
     * Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision.
     * @immutable
     */
    revision?: string | null;
    /**
     * Represents the time this NotificationConfig was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Represents the time this NotificationConfig was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /** Rsvp confirmation. */
    rsvpConfirmation?: EmailNotificationConfig;
    /** New spots available. */
    newSpotsAvailable?: EmailNotificationConfig;
    /** Event cancelation. */
    eventCancelation?: EmailNotificationConfig;
    /** Event reminder. */
    upcomingEventReminder?: EmailNotificationConfig;
    /** Order confirmation. */
    orderConfirmation?: EmailNotificationConfig;
    /** Ticket confirmation. */
    ticketConfirmation?: EmailNotificationConfig;
    /** Invoice. */
    invoice?: EmailNotificationConfig;
    /** Order confirmation with tickets link. */
    orderConfirmationWithTicketsLink?: EmailNotificationConfig;
}
interface EmailNotificationConfig {
    /**
     * Predefined id of the notification type.
     * @readonly
     */
    notificationType?: EmailNotificationTypeWithLiterals;
    /** Email template values. */
    template?: EmailTemplate;
    /**
     * Desired timing of the notification in hours respectfully to event start time.
     * For example if value is 0 then notification is sent at the start of the event.
     */
    reminderTime?: EmailNotificationReminderTimeWithLiterals;
    /** When true the notification will be sent when certain trigger occurs. */
    sendingEnabled?: boolean | null;
}
declare enum EmailNotificationType {
    /** Default value. This value is unused. */
    UNKNOWN_NOTIFICATION_TYPE = "UNKNOWN_NOTIFICATION_TYPE",
    /** Triggered when site user RSVP to the event. */
    EMAIL_RSVP_CONFIRMATION = "EMAIL_RSVP_CONFIRMATION",
    /** Triggered for waiting guests when additional RSVP spots appears in the fully booked event. */
    EMAIL_NEW_SPOTS_AVAILABLE = "EMAIL_NEW_SPOTS_AVAILABLE",
    /** Triggered when event is canceled. */
    EMAIL_EVENT_CANCELATION = "EMAIL_EVENT_CANCELATION",
    /** Triggered before the event start time. */
    EMAIL_UPCOMING_EVENT_REMINDER = "EMAIL_UPCOMING_EVENT_REMINDER",
    /** Triggered when site user creates Order. */
    EMAIL_ORDER_CONFIRMATION = "EMAIL_ORDER_CONFIRMATION",
    /** Triggered when resending ticket to ticket holder. */
    EMAIL_TICKET_CONFIRMATION = "EMAIL_TICKET_CONFIRMATION",
    /** Triggered when sending invoice. Currently only `enabled` flag update is supported. */
    EMAIL_INVOICE = "EMAIL_INVOICE"
}
/** @enumType */
type EmailNotificationTypeWithLiterals = EmailNotificationType | 'UNKNOWN_NOTIFICATION_TYPE' | 'EMAIL_RSVP_CONFIRMATION' | 'EMAIL_NEW_SPOTS_AVAILABLE' | 'EMAIL_EVENT_CANCELATION' | 'EMAIL_UPCOMING_EVENT_REMINDER' | 'EMAIL_ORDER_CONFIRMATION' | 'EMAIL_TICKET_CONFIRMATION' | 'EMAIL_INVOICE';
interface EmailTemplate {
    /**
     * Email subject.
     * @minLength 1
     * @maxLength 100
     */
    subject?: string | null;
    /**
     * Plain text message body.
     * @minLength 1
     * @maxLength 1000
     */
    body?: string | null;
    /** Description link visibility and display text */
    descriptionLink?: Link;
    /** Calendar link visibility and display text */
    calendarLink?: Link;
    /** Online conferencing link visibility and display text */
    onlineConferencingLink?: Link;
    /** When true the tickets are attached to the order confirmation email. */
    includeTickets?: boolean | null;
}
interface Link {
    /** When true the link is added to the email. */
    display?: boolean | null;
    /**
     * Text of the link.
     * @maxLength 60
     */
    linkText?: string | null;
}
declare enum EmailNotificationReminderTime {
    /** Default value. This value is unused. */
    UNKNOWN_REMINDER_TIME = "UNKNOWN_REMINDER_TIME",
    /** Notification is sent instantly */
    INSTANT = "INSTANT",
    /** 24 hours prior */
    BEFORE_1_DAY = "BEFORE_1_DAY",
    /** 3 days prior */
    BEFORE_3_DAYS = "BEFORE_3_DAYS",
    /** 7 days prior */
    BEFORE_1_WEEK = "BEFORE_1_WEEK",
    /** 1 hour prior */
    BEFORE_1_HOUR = "BEFORE_1_HOUR",
    /** 30 minutes prior */
    BEFORE_30_MINUTES = "BEFORE_30_MINUTES"
}
/** @enumType */
type EmailNotificationReminderTimeWithLiterals = EmailNotificationReminderTime | 'UNKNOWN_REMINDER_TIME' | 'INSTANT' | 'BEFORE_1_DAY' | 'BEFORE_3_DAYS' | 'BEFORE_1_WEEK' | 'BEFORE_1_HOUR' | 'BEFORE_30_MINUTES';
interface TriggerNotificationRequest extends TriggerNotificationRequestNotificationOneOf, TriggerNotificationRequestGuestsOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
/** @oneof */
interface TriggerNotificationRequestNotificationOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
}
/** @oneof */
interface TriggerNotificationRequestGuestsOneOf {
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
declare enum PushNotificationType {
    /** This is default value. This value is unused. */
    UNKNOWN_PUSH_TYPE = "UNKNOWN_PUSH_TYPE",
    /** Triggered when event is updated. */
    PUSH_EVENT_UPDATED = "PUSH_EVENT_UPDATED",
    /** Triggered when event is canceled. */
    PUSH_EVENT_CANCELATION = "PUSH_EVENT_CANCELATION",
    /** Triggered before the event start time. */
    PUSH_UPCOMING_EVENT_REMINDER = "PUSH_UPCOMING_EVENT_REMINDER",
    /** Triggered when event is created. */
    PUSH_EVENT_CREATED = "PUSH_EVENT_CREATED"
}
/** @enumType */
type PushNotificationTypeWithLiterals = PushNotificationType | 'UNKNOWN_PUSH_TYPE' | 'PUSH_EVENT_UPDATED' | 'PUSH_EVENT_CANCELATION' | 'PUSH_UPCOMING_EVENT_REMINDER' | 'PUSH_EVENT_CREATED';
/** Single guest associated to the RSVP */
interface RsvpGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Rsvp id
     * @format GUID
     */
    rsvpId?: string;
}
/** Single guest associated to the Order */
interface OrderGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Order number
     * @maxLength 36
     */
    orderNumber?: string;
}
/** All event guest from RSVPs and Orders */
interface EventGuests {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
}
/** Multiple guests associated to Tickets */
interface TicketGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Order number
     * @maxLength 36
     */
    orderNumber?: string | null;
    /**
     * Ticket numbers must be from the same order only.
     * @minSize 1
     * @maxSize 100
     * @maxLength 36
     */
    ticketNumber?: string[];
}
interface TriggerNotificationResponse {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface Empty {
}
interface EventUpdated {
    /** Event update timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event location. */
    location?: Location;
    /** Event schedule configuration. */
    scheduleConfig?: ScheduleConfig;
    /** Event title. */
    title?: string;
    /**
     * Whether schedule configuration was updated.
     * @deprecated
     */
    scheduleConfigUpdated?: boolean;
    /** Updated event */
    event?: Event;
}
interface Location {
    /**
     * Location name.
     * @maxLength 50
     */
    name?: string | null;
    /** Location map coordinates. */
    coordinates?: MapCoordinates;
    /**
     * Single line address representation.
     * @maxLength 300
     */
    address?: string | null;
    /** Location type. */
    type?: LocationTypeWithLiterals;
    /**
     * Full address derived from formatted single line `address`.
     * When `full_address` is used to create or update the event, deprecated `address` and `coordinates` are ignored.
     * If provided `full_address` has empty `formatted_address` or `coordinates`, it will be auto-completed using Atlas service.
     *
     * Migration notes:
     * - `full_address.formatted_address` is equivalent to `address`.
     * - `full_address.geocode` is equivalent to `coordinates`.
     */
    fullAddress?: Address;
    /**
     * Defines event location as TBD (To Be Determined).
     * When event location is not yet defined, `name` is displayed instead of location address.
     * `coordinates`, `address`, `type` and `full_address` are not required when location is TBD.
     */
    tbd?: boolean | null;
}
interface MapCoordinates {
    /**
     * Latitude.
     * @min -90
     * @max 90
     */
    lat?: number;
    /**
     * Longitude.
     * @min -180
     * @max 180
     */
    lng?: number;
}
declare enum LocationType {
    VENUE = "VENUE",
    ONLINE = "ONLINE"
}
/** @enumType */
type LocationTypeWithLiterals = LocationType | 'VENUE' | 'ONLINE';
/** Physical address */
interface Address extends AddressStreetOneOf {
    /** a break down of the street to number and street name */
    streetAddress?: StreetAddress;
    /** Main address line (usually street and number) as free text */
    addressLine1?: string | null;
    /**
     * country code
     * @format COUNTRY
     */
    country?: string | null;
    /** subdivision (usually state or region) code according to ISO 3166-2 */
    subdivision?: string | null;
    /** city name */
    city?: string | null;
    /** zip/postal code */
    postalCode?: string | null;
    /** Free text providing more detailed address info. Usually contains Apt, Suite, Floor */
    addressLine2?: string | null;
    /** A string containing the human-readable address of this location */
    formatted?: string | null;
    /** coordinates of the physical address */
    location?: AddressLocation;
    /** country full-name */
    countryFullname?: string | null;
    /**
     * multi-level subdivisions from top to bottom
     * @maxSize 6
     */
    subdivisions?: Subdivision[];
}
/** @oneof */
interface AddressStreetOneOf {
    /** a break down of the street to number and street name */
    streetAddress?: StreetAddress;
    /** Main address line (usually street and number) as free text */
    addressLine?: string | null;
}
interface StreetAddress {
    /** street number */
    number?: string;
    /** street name */
    name?: string;
}
interface AddressLocation {
    /**
     * address latitude coordinates
     * @min -90
     * @max 90
     */
    latitude?: number | null;
    /**
     * address longitude coordinates
     * @min -180
     * @max 180
     */
    longitude?: number | null;
}
interface Subdivision {
    /** subdivision short code */
    code?: string;
    /** subdivision full-name */
    name?: string;
}
declare enum SubdivisionType {
    UNKNOWN_SUBDIVISION_TYPE = "UNKNOWN_SUBDIVISION_TYPE",
    /** State */
    ADMINISTRATIVE_AREA_LEVEL_1 = "ADMINISTRATIVE_AREA_LEVEL_1",
    /** County */
    ADMINISTRATIVE_AREA_LEVEL_2 = "ADMINISTRATIVE_AREA_LEVEL_2",
    /** City/town */
    ADMINISTRATIVE_AREA_LEVEL_3 = "ADMINISTRATIVE_AREA_LEVEL_3",
    /** Neighborhood/quarter */
    ADMINISTRATIVE_AREA_LEVEL_4 = "ADMINISTRATIVE_AREA_LEVEL_4",
    /** Street/block */
    ADMINISTRATIVE_AREA_LEVEL_5 = "ADMINISTRATIVE_AREA_LEVEL_5",
    /** ADMINISTRATIVE_AREA_LEVEL_0. Indicates the national political entity, and is typically the highest order type returned by the Geocoder. */
    COUNTRY = "COUNTRY"
}
interface ScheduleConfig {
    /**
     * Defines event as TBD (To Be Determined) schedule.
     * When event time is not yet defined, TBD message is displayed instead of event start and end times.
     * `startDate`, `endDate` and `timeZoneId` are not required when schedule is TBD.
     */
    scheduleTbd?: boolean;
    /**
     * TBD message.
     * @maxLength 100
     */
    scheduleTbdMessage?: string | null;
    /** Event start timestamp. */
    startDate?: Date | null;
    /** Event end timestamp. */
    endDate?: Date | null;
    /**
     * Event time zone ID in TZ database format, e.g., `EST`, `America/Los_Angeles`.
     * @maxLength 100
     */
    timeZoneId?: string | null;
    /** Whether end date is hidden in the formatted schedule. */
    endDateHidden?: boolean;
    /** Whether time zone is displayed in formatted schedule. */
    showTimeZone?: boolean;
    /** Event recurrences. */
    recurrences?: Recurrences;
}
interface Recurrences {
    /**
     * Event occurrences.
     * @maxSize 1000
     */
    occurrences?: Occurrence[];
    /**
     * Recurring event category ID.
     * @readonly
     */
    categoryId?: string | null;
    /**
     * Recurrence status.
     * @readonly
     */
    status?: StatusWithLiterals;
}
interface Occurrence {
    /** Event start timestamp. */
    startDate?: Date | null;
    /** Event end timestamp. */
    endDate?: Date | null;
    /**
     * Event time zone ID in TZ database format, e.g., `EST`, `America/Los_Angeles`.
     * @maxLength 100
     */
    timeZoneId?: string | null;
    /** Whether time zone is displayed in formatted schedule. */
    showTimeZone?: boolean;
}
declare enum Status {
    /** Event occurs only once. */
    ONE_TIME = "ONE_TIME",
    /** Event is recurring. */
    RECURRING = "RECURRING",
    /** Marks the next upcoming occurrence of the recurring event. */
    RECURRING_NEXT = "RECURRING_NEXT",
    /** Marks the most recent ended occurrence of the recurring event. */
    RECURRING_LAST_ENDED = "RECURRING_LAST_ENDED",
    /** Marks the most recent canceled occurrence of the recurring event. */
    RECURRING_LAST_CANCELED = "RECURRING_LAST_CANCELED"
}
/** @enumType */
type StatusWithLiterals = Status | 'ONE_TIME' | 'RECURRING' | 'RECURRING_NEXT' | 'RECURRING_LAST_ENDED' | 'RECURRING_LAST_CANCELED';
interface Event {
    /**
     * Event ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** Event location. */
    location?: Location;
    /** Event scheduling. */
    scheduling?: Scheduling;
    /** Event title. */
    title?: string;
    /** Event description. */
    description?: string;
    /** Rich-text content that are displayed in a site's "About Event" section (HTML). */
    about?: string;
    /** Main event image. */
    mainImage?: string;
    /** Event slug URL (generated from event title). */
    slug?: string;
    /** ISO 639-1 language code of the event (used in content translations). */
    language?: string;
    /** Event creation timestamp. */
    created?: Date | null;
    /** Event modified timestamp. */
    modified?: Date | null;
    /** Event status. */
    status?: EventStatusWithLiterals;
    /** RSVP or ticketing registration details. */
    registration?: Registration;
    /** "Add to calendar" URLs. */
    calendarLinks?: CalendarLinks;
    /** Event page URL components. */
    eventPageUrl?: SiteUrl;
    /** Event registration form. */
    form?: Form;
    /** Event dashboard summary of RSVP / ticket sales. */
    dashboard?: Dashboard;
    /** Instance ID of the site where event is hosted. */
    instanceId?: string;
    /** Guest list configuration. */
    guestListConfig?: GuestListConfig;
    /**
     * Event creator user ID.
     * @maxLength 36
     */
    userId?: string;
    /** Event discussion feed. For internal use. */
    feed?: Feed;
    /** Online conferencing details. */
    onlineConferencing?: OnlineConferencing;
    /** SEO settings. */
    seoSettings?: SeoSettings;
    /** Assigned contacts label key. */
    assignedContactsLabel?: string | null;
    /** Agenda details. */
    agenda?: Agenda;
    /** Categories this event is assigned to. */
    categories?: Category[];
    /** Visual settings for event. */
    eventDisplaySettings?: EventDisplaySettings;
    /** Rich content that are displayed in a site's "About Event" section. Successor to `about` field. */
    longDescription?: RichContent;
    /**
     * Event publish timestamp.
     * @readonly
     */
    publishedDate?: Date | null;
}
interface Scheduling {
    /** Schedule configuration. */
    config?: ScheduleConfig;
    /** Formatted schedule representation. */
    formatted?: string;
    /** Formatted start date of the event (empty for TBD schedules). */
    startDateFormatted?: string;
    /** Formatted start time of the event (empty for TBD schedules). */
    startTimeFormatted?: string;
    /** Formatted end date of the event (empty for TBD schedules or when end date is hidden). */
    endDateFormatted?: string;
    /** Formatted end time of the event (empty for TBD schedules or when end date is hidden). */
    endTimeFormatted?: string;
}
declare enum EventStatus {
    /** Event is public and scheduled to start */
    SCHEDULED = "SCHEDULED",
    /** Event has started */
    STARTED = "STARTED",
    /** Event has ended */
    ENDED = "ENDED",
    /** Event was canceled */
    CANCELED = "CANCELED"
}
/** @enumType */
type EventStatusWithLiterals = EventStatus | 'SCHEDULED' | 'STARTED' | 'ENDED' | 'CANCELED';
interface Registration {
    /** Event type. */
    type?: EventTypeWithLiterals;
    /** Event registration status. */
    status?: RegistrationStatusWithLiterals;
    /** RSVP collection details. */
    rsvpCollection?: RsvpCollection;
    /** Ticketing details. */
    ticketing?: Ticketing;
    /** External registration details. */
    external?: ExternalEvent;
    /** Types of users allowed to register. */
    restrictedTo?: VisitorTypeWithLiterals;
    /** Initial event type which was set when creating an event. */
    initialType?: EventTypeWithLiterals;
}
declare enum EventType {
    /** Type not available for this request fieldset */
    NA_EVENT_TYPE = "NA_EVENT_TYPE",
    /** Registration via RSVP */
    RSVP = "RSVP",
    /** Registration via ticket purchase */
    TICKETS = "TICKETS",
    /** External registration */
    EXTERNAL = "EXTERNAL",
    /** Registration not available */
    NO_REGISTRATION = "NO_REGISTRATION"
}
/** @enumType */
type EventTypeWithLiterals = EventType | 'NA_EVENT_TYPE' | 'RSVP' | 'TICKETS' | 'EXTERNAL' | 'NO_REGISTRATION';
declare enum RegistrationStatus {
    /** Registration status is not applicable */
    NA_REGISTRATION_STATUS = "NA_REGISTRATION_STATUS",
    /** Registration to event is closed */
    CLOSED = "CLOSED",
    /** Registration to event is closed manually */
    CLOSED_MANUALLY = "CLOSED_MANUALLY",
    /** Registration is open via RSVP */
    OPEN_RSVP = "OPEN_RSVP",
    /** Registration to event waitlist is open via RSVP */
    OPEN_RSVP_WAITLIST = "OPEN_RSVP_WAITLIST",
    /** Registration is open via ticket purchase */
    OPEN_TICKETS = "OPEN_TICKETS",
    /** Registration is open via external URL */
    OPEN_EXTERNAL = "OPEN_EXTERNAL",
    /** Registration will be open via RSVP */
    SCHEDULED_RSVP = "SCHEDULED_RSVP"
}
/** @enumType */
type RegistrationStatusWithLiterals = RegistrationStatus | 'NA_REGISTRATION_STATUS' | 'CLOSED' | 'CLOSED_MANUALLY' | 'OPEN_RSVP' | 'OPEN_RSVP_WAITLIST' | 'OPEN_TICKETS' | 'OPEN_EXTERNAL' | 'SCHEDULED_RSVP';
interface RsvpCollection {
    /** RSVP collection configuration. */
    config?: RsvpCollectionConfig;
}
interface RsvpCollectionConfig {
    /** Defines the supported RSVP statuses. */
    rsvpStatusOptions?: RsvpStatusOptionsWithLiterals;
    /**
     * Total guest limit available to register to the event.
     * Additional guests per RSVP are counted towards total guests.
     */
    limit?: number | null;
    /** Whether a waitlist is opened when total guest limit is reached, allowing guests to create RSVP with WAITING RSVP status. */
    waitlist?: boolean;
    /** Registration start timestamp. */
    startDate?: Date | null;
    /** Registration end timestamp. */
    endDate?: Date | null;
}
declare enum RsvpStatusOptions {
    /** Only YES RSVP status is available for RSVP registration */
    YES_ONLY = "YES_ONLY",
    /** YES and NO RSVP status options are available for the registration */
    YES_AND_NO = "YES_AND_NO"
}
/** @enumType */
type RsvpStatusOptionsWithLiterals = RsvpStatusOptions | 'YES_ONLY' | 'YES_AND_NO';
interface Ticketing {
    /**
     * Deprecated.
     * @deprecated
     */
    lowestPrice?: string | null;
    /**
     * Deprecated.
     * @deprecated
     */
    highestPrice?: string | null;
    /** Currency used in event transactions. */
    currency?: string | null;
    /** Ticketing configuration. */
    config?: TicketingConfig;
    /**
     * Price of lowest priced ticket.
     * @readonly
     */
    lowestTicketPrice?: Money;
    /**
     * Price of highest priced ticket.
     * @readonly
     */
    highestTicketPrice?: Money;
    /**
     * Formatted price of lowest priced ticket.
     * @readonly
     */
    lowestTicketPriceFormatted?: string | null;
    /**
     * Formatted price of highest priced ticket.
     * @readonly
     */
    highestTicketPriceFormatted?: string | null;
    /**
     * Whether all tickets are sold for this event.
     * @readonly
     */
    soldOut?: boolean | null;
}
interface TicketingConfig {
    /** Whether the form must be filled out separately for each ticket. */
    guestAssignedTickets?: boolean;
    /** Tax configuration. */
    taxConfig?: TaxConfig;
    /**
     * Limit of tickets that can be purchased per order, default 20.
     * @max 50
     */
    ticketLimitPerOrder?: number;
    /**
     * Duration for which the tickets being bought are reserved.
     * @min 5
     * @max 30
     */
    reservationDurationInMinutes?: number | null;
}
interface TaxConfig {
    /** Tax application settings. */
    type?: TaxTypeWithLiterals;
    /**
     * Tax name.
     * @minLength 1
     * @maxLength 10
     */
    name?: string | null;
    /**
     * Tax rate (e.g.,`21.55`).
     * @decimalValue options { gte:0.001, lte:100, maxScale:3 }
     */
    rate?: string | null;
    /** Applies taxes for donations, default true. */
    appliesToDonations?: boolean | null;
}
declare enum TaxType {
    /** Tax is included in the ticket price. */
    INCLUDED = "INCLUDED",
    /** Tax is added to the order at the checkout. */
    ADDED = "ADDED",
    /** Tax is added to the final total at the checkout. */
    ADDED_AT_CHECKOUT = "ADDED_AT_CHECKOUT"
}
/** @enumType */
type TaxTypeWithLiterals = TaxType | 'INCLUDED' | 'ADDED' | 'ADDED_AT_CHECKOUT';
interface Money {
    /**
     * *Deprecated:** Use `value` instead.
     * @format DECIMAL_VALUE
     * @deprecated
     */
    amount?: string;
    /**
     * Three-letter currency code in [ISO-4217 alphabetic](https://en.wikipedia.org/wiki/ISO_4217#Active_codes) format.
     * @format CURRENCY
     */
    currency?: string;
    /**
     * Monetary amount. Decimal string with a period as a decimal separator (e.g., 3.99). Optionally, starts with a single (-), to indicate that the amount is negative.
     * @format DECIMAL_VALUE
     */
    value?: string | null;
}
interface ExternalEvent {
    /** External event registration URL. */
    registration?: string;
}
declare enum VisitorType {
    /** Site visitor (including member) */
    VISITOR = "VISITOR",
    /** Site member */
    MEMBER = "MEMBER",
    /** Site visitor or member */
    VISITOR_OR_MEMBER = "VISITOR_OR_MEMBER"
}
/** @enumType */
type VisitorTypeWithLiterals = VisitorType | 'VISITOR' | 'MEMBER' | 'VISITOR_OR_MEMBER';
interface CalendarLinks {
    /** "Add to Google calendar" URL. */
    google?: string;
    /** "Download ICS calendar file" URL. */
    ics?: string;
}
/** Site URL components */
interface SiteUrl {
    /**
     * Base URL. For premium sites, this will be the domain.
     * For free sites, this would be site URL (e.g `mysite.wixsite.com/mysite`)
     */
    base?: string;
    /** The path to that page - e.g `/my-events/weekly-meetup-2` */
    path?: string;
}
/**
 * The form defines which elements are displayed to a site visitor during the registration process (RSVP or checkout).
 * It also contains customizable messages and labels.
 *
 *
 * A form is an ordered list of controls (blocks), which accept guest information into a field input.
 *
 * Each control contains one or more nested inputs. For example, `Name` control has two inputs:
 * - First Name
 * - Last Name
 *
 * By default, name and email controls are always required and are pinned to the top of the form.
 */
interface Form {
    /** Nested fields as an ordered list. */
    controls?: InputControl[];
    /**
     * Set of defined form messages displayed in the UI before, during, and after a registration flow.
     * Includes the configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
     */
    messages?: FormMessages;
}
/**
 * A block of nested fields.
 * Used to aggregate similar inputs like First Name and Last Name.
 */
interface InputControl {
    /** Field control type. */
    type?: InputControlTypeWithLiterals;
    /** Whether the control is mandatory (such as `name` & `email`). When `true`, only the label can be changed. */
    system?: boolean;
    /**
     * Deprecated: Use `id` or `_id`.
     * @deprecated
     */
    name?: string;
    /** Child inputs. */
    inputs?: Input[];
    /**
     * *Deprecated:** Use `controls.inputs.label`.
     * @deprecated
     */
    label?: string;
    /** Field controls are sorted by this value in ascending order. */
    orderIndex?: number;
    /** Unique control ID. */
    _id?: string;
    /**
     * Whether the input control is deleted.
     * @readonly
     */
    deleted?: boolean | null;
}
declare enum InputControlType {
    /** Single text value field. */
    INPUT = "INPUT",
    /** Single text value field with multiple lines. */
    TEXTAREA = "TEXTAREA",
    /** Single-choice field with predefined values. */
    DROPDOWN = "DROPDOWN",
    /** Single-choice field with predefined values. */
    RADIO = "RADIO",
    /** Multiple-choice field with predefined values. */
    CHECKBOX = "CHECKBOX",
    /** Fields for entering first and last names. */
    NAME = "NAME",
    /** Fields for additional guests and their respective names. */
    GUEST_CONTROL = "GUEST_CONTROL",
    /** Single-line address field. */
    ADDRESS_SHORT = "ADDRESS_SHORT",
    /** Full address field with multiple lines. */
    ADDRESS_FULL = "ADDRESS_FULL",
    /** Fields for entering year, month, and day. */
    DATE = "DATE"
}
/** @enumType */
type InputControlTypeWithLiterals = InputControlType | 'INPUT' | 'TEXTAREA' | 'DROPDOWN' | 'RADIO' | 'CHECKBOX' | 'NAME' | 'GUEST_CONTROL' | 'ADDRESS_SHORT' | 'ADDRESS_FULL' | 'DATE';
/** Child inputs. */
interface Input {
    /** Field name. */
    name?: string;
    /**
     * *Deprecated:** Use `controls.inputs.type.TEXT_ARRAY`.
     * @deprecated
     */
    array?: boolean;
    /** Main field label. */
    label?: string;
    /** Additional labels for multi-valued fields such as address. */
    additionalLabels?: Record<string, string>;
    /** Predefined choice options for fields, such as dropdown. */
    options?: string[];
    /** Whether field is mandatory. */
    mandatory?: boolean;
    /** Maximum number of accepted characters (relevant for text fields). */
    maxLength?: number;
    /**
     * Type which determines field format.
     * Used to validate submitted response.
     */
    type?: ValueTypeWithLiterals;
    /**
     * The maximum number of accepted values for array input.
     *
     * **Note:** Only applicable for `TEXT_ARRAY` input fields.
     */
    maxSize?: number | null;
    /**
     * Default option initially selected when an input has multiple choices.
     *
     * Defaults to first (0th) option, if not configured.
     * Currently only applicable for `type.dropdown`.
     */
    defaultOptionSelection?: OptionSelection;
    /**
     * Additional labels for multi-valued fields, such as address.
     * @readonly
     */
    labels?: Label[];
}
declare enum ValueType {
    TEXT = "TEXT",
    NUMBER = "NUMBER",
    TEXT_ARRAY = "TEXT_ARRAY",
    DATE_TIME = "DATE_TIME",
    ADDRESS = "ADDRESS"
}
/** @enumType */
type ValueTypeWithLiterals = ValueType | 'TEXT' | 'NUMBER' | 'TEXT_ARRAY' | 'DATE_TIME' | 'ADDRESS';
/**
 * Describes initially selected option when an input has multiple choices.
 * Defaults to first (0th) option if not configured.
 */
interface OptionSelection extends OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
/** @oneof */
interface OptionSelectionSelectedOptionOneOf {
    /**
     * 0-based index from predefined `controls.inputs.options` which is initial selection.
     * @max 199
     */
    optionIndex?: number;
    /**
     * Placeholder hint describing expected choices, such as "Please select".
     * Considered an empty choice.
     * @maxLength 200
     */
    placeholderText?: string;
}
interface Label {
    /** Field name. */
    name?: string;
    /** Field label. */
    label?: string;
}
/**
 * Defines form messages shown in UI before, during, and after registration flow.
 * It enables configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
 */
interface FormMessages {
    /** RSVP form ([SDK](https://dev.wix.com/docs/sdk/backend-modules/events/rsvp-v2/introduction) | [REST](https://dev.wix.com/docs/rest/business-solutions/events/rsvp-v2/introduction)) messages. */
    rsvp?: RsvpFormMessages;
    /** Checkout form messages. */
    checkout?: CheckoutFormMessages;
    /** Messages shown when event registration is closed. */
    registrationClosed?: RegistrationClosedMessages;
    /** Messages shown when event tickets are unavailable. */
    ticketsUnavailable?: TicketsUnavailableMessages;
}
interface RsvpFormMessages {
    /** Label text indicating RSVP's `status` is `"YES"`. */
    rsvpYesOption?: string;
    /** Label text indicating RSVP's `status` is `"NO"`. */
    rsvpNoOption?: string;
    /** Messages displayed when an RSVP's `status` is set to `"YES"`. */
    positiveMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"WAITLIST"`, for when the event is full and a waitlist is available). */
    waitlistMessages?: Positive;
    /** Messages displayed when an RSVP's `status` is set to `"NO"`. */
    negativeMessages?: Negative;
    /** "Submit form" call-to-action label text. */
    submitActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface PositiveResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarActionLabel?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Confirmation messages shown after registration. */
interface NegativeResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** "Share event" call-to-action label text. */
    shareActionLabel?: string;
}
/** Set of messages shown during registration when RSVP response is positive. */
interface Positive {
    /** Main form title for positive response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: PositiveResponseConfirmation;
}
/** A set of messages shown during registration with negative response */
interface Negative {
    /** Main form title for negative response. */
    title?: string;
    /** Confirmation messages shown after registration. */
    confirmation?: NegativeResponseConfirmation;
}
interface CheckoutFormMessages {
    /** Main form title for response. */
    title?: string;
    /** Submit form call-to-action label text. */
    submitActionLabel?: string;
    /** Confirmation messages shown after checkout. */
    confirmation?: ResponseConfirmation;
}
/** Confirmation messages shown after checkout. */
interface ResponseConfirmation {
    /** Confirmation message title. */
    title?: string;
    /** Confirmation message text. */
    message?: string;
    /** "Download tickets" call-to-action label text. */
    downloadTicketsLabel?: string;
    /** "Add to calendar" call-to-action label text. */
    addToCalendarLabel?: string;
    /** "Share event" call-to-action label text. */
    shareEventLabel?: string;
}
interface RegistrationClosedMessages {
    /** Message shown when event registration is closed. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface TicketsUnavailableMessages {
    /** Message shown when event tickets are unavailable. */
    message?: string;
    /** "Explore other events" call-to-action label text. */
    exploreEventsActionLabel?: string;
}
interface Dashboard {
    /** Guest RSVP summary. */
    rsvpSummary?: RsvpSummary;
    /**
     * Summary of revenue and tickets sold.
     * (Archived orders are not included).
     */
    ticketingSummary?: TicketingSummary;
}
interface RsvpSummary {
    /** Total number of RSVPs. */
    total?: number;
    /** Number of RSVPs with status `YES`. */
    yes?: number;
    /** Number of RSVPs with status `NO`. */
    no?: number;
    /** Number of RSVPs in waitlist. */
    waitlist?: number;
}
interface TicketingSummary {
    /** Number of tickets sold. */
    tickets?: number;
    /**
     * Total revenue, excluding fees.
     * (taxes and payment provider fees are not deducted.)
     */
    revenue?: Money;
    /** Whether currency is locked and cannot be changed (generally occurs after the first order in the specified currency has been created). */
    currencyLocked?: boolean;
    /** Number of orders placed. */
    orders?: number;
    /** Total balance of confirmed transactions. */
    totalSales?: Money;
}
interface GuestListConfig {
    /** Whether members can see other members attending the event (defaults to true). */
    publicGuestList?: boolean;
}
interface Feed {
    /** Event discussion feed token. */
    token?: string;
}
interface OnlineConferencing {
    config?: OnlineConferencingConfig;
    session?: OnlineConferencingSession;
}
interface OnlineConferencingConfig {
    /**
     * Whether online conferencing is enabled (not supported for TBD schedules).
     * When enabled, links to join conferencing are generated and provided to guests.
     */
    enabled?: boolean;
    /**
     * Conferencing provider ID.
     * @format GUID
     */
    providerId?: string | null;
    /** Conference type */
    conferenceType?: ConferenceTypeWithLiterals;
}
declare enum ConferenceType {
    /** Everyone in the meeting can publish and subscribe video and audio. */
    MEETING = "MEETING",
    /** Guests can only subscribe to video and audio. */
    WEBINAR = "WEBINAR"
}
/** @enumType */
type ConferenceTypeWithLiterals = ConferenceType | 'MEETING' | 'WEBINAR';
interface OnlineConferencingSession {
    /**
     * Link for event host to start the online conference session.
     * @readonly
     */
    hostLink?: string;
    /**
     * Link for guests to join the online conference session.
     * @readonly
     */
    guestLink?: string;
    /**
     * The password required to join online conferencing session (when relevant).
     * @readonly
     */
    password?: string | null;
    /**
     * Indicates that session was created successfully on providers side.
     * @readonly
     */
    sessionCreated?: boolean | null;
    /**
     * Unique session id
     * @readonly
     */
    sessionId?: string | null;
}
interface SeoSettings {
    /**
     * URL slug
     * @maxLength 130
     */
    slug?: string;
    /** Advanced SEO data */
    advancedSeoData?: SeoSchema;
    /**
     * Hidden from SEO Site Map
     * @readonly
     */
    hidden?: boolean | null;
}
/**
 * The SEO schema object contains data about different types of meta tags. It makes sure that the information about your page is presented properly to search engines.
 * The search engines use this information for ranking purposes, or to display snippets in the search results.
 * This data will override other sources of tags (for example patterns) and will be included in the <head> section of the HTML document, while not being displayed on the page itself.
 */
interface SeoSchema {
    /** SEO tag information. */
    tags?: Tag[];
    /** SEO general settings. */
    settings?: Settings;
}
interface Keyword {
    /** Keyword value. */
    term?: string;
    /** Whether the keyword is the main focus keyword. */
    isMain?: boolean;
    /**
     * The source that added the keyword terms to the SEO settings.
     * @maxLength 1000
     */
    origin?: string | null;
}
interface Tag {
    /**
     * SEO tag type.
     *
     *
     * Supported values: `title`, `meta`, `script`, `link`.
     */
    type?: string;
    /**
     * A `{"key": "value"}` pair object where each SEO tag property (`"name"`, `"content"`, `"rel"`, `"href"`) contains a value.
     * For example: `{"name": "description", "content": "the description itself"}`.
     */
    props?: Record<string, any> | null;
    /** SEO tag meta data. For example, `{"height": 300, "width": 240}`. */
    meta?: Record<string, any> | null;
    /** SEO tag inner content. For example, `<title> inner content </title>`. */
    children?: string;
    /** Whether the tag is a custom tag. */
    custom?: boolean;
    /** Whether the tag is disabled. */
    disabled?: boolean;
}
interface Settings {
    /**
     * Whether the Auto Redirect feature, which creates `301 redirects` on a slug change, is enabled.
     *
     *
     * Default: `false` (Auto Redirect is enabled.)
     */
    preventAutoRedirect?: boolean;
    /**
     * User-selected keyword terms for a specific page.
     * @maxSize 5
     */
    keywords?: Keyword[];
}
interface Agenda {
    /** Whether the schedule is enabled for the event. */
    enabled?: boolean;
    /**
     * Agenda page URL.
     * @readonly
     */
    pageUrl?: SiteUrl;
}
interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     *
     * `MANUAL`: Category is created manually by the user.
     * `AUTO`: Category is created automatically.
     * `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission scope is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
interface CategoryCounts {
    /** Total number of draft events assigned to the category. */
    assignedEventsCount?: number | null;
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedDraftEventsCount?: number | null;
}
declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
interface EventDisplaySettings {
    /** Whether event details button is hidden. Only available for events with no registration. */
    hideEventDetailsButton?: boolean | null;
    /** Disables event details page visibility. If event has an external registration configured visitors will be redirected from this page. */
    hideEventDetailsPage?: boolean | null;
}
interface LabellingSettings {
}
interface RichContent {
    /** Node objects representing a rich content document. */
    nodes?: Node[];
    /** Object metadata. */
    metadata?: Metadata;
    /** Global styling for header, paragraph, block quote, and code block nodes in the object. */
    documentStyle?: DocumentStyle;
}
interface Node extends NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
    /** Node type. Use `APP_EMBED` for nodes that embed content from other Wix apps. Use `EMBED` to embed content in [oEmbed](https://oembed.com/) format. */
    type?: NodeTypeWithLiterals;
    /** Node ID. */
    id?: string;
    /** A list of child nodes. */
    nodes?: Node[];
    /** Padding and background color styling for the node. */
    style?: NodeStyle;
}
/** @oneof */
interface NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
}
declare enum NodeType {
    PARAGRAPH = "PARAGRAPH",
    TEXT = "TEXT",
    HEADING = "HEADING",
    BULLETED_LIST = "BULLETED_LIST",
    ORDERED_LIST = "ORDERED_LIST",
    LIST_ITEM = "LIST_ITEM",
    BLOCKQUOTE = "BLOCKQUOTE",
    CODE_BLOCK = "CODE_BLOCK",
    VIDEO = "VIDEO",
    DIVIDER = "DIVIDER",
    FILE = "FILE",
    GALLERY = "GALLERY",
    GIF = "GIF",
    HTML = "HTML",
    IMAGE = "IMAGE",
    LINK_PREVIEW = "LINK_PREVIEW",
    /** @deprecated */
    MAP = "MAP",
    POLL = "POLL",
    APP_EMBED = "APP_EMBED",
    BUTTON = "BUTTON",
    COLLAPSIBLE_LIST = "COLLAPSIBLE_LIST",
    TABLE = "TABLE",
    EMBED = "EMBED",
    COLLAPSIBLE_ITEM = "COLLAPSIBLE_ITEM",
    COLLAPSIBLE_ITEM_TITLE = "COLLAPSIBLE_ITEM_TITLE",
    COLLAPSIBLE_ITEM_BODY = "COLLAPSIBLE_ITEM_BODY",
    TABLE_CELL = "TABLE_CELL",
    TABLE_ROW = "TABLE_ROW",
    EXTERNAL = "EXTERNAL",
    AUDIO = "AUDIO",
    CAPTION = "CAPTION",
    LAYOUT = "LAYOUT",
    LAYOUT_CELL = "LAYOUT_CELL"
}
/** @enumType */
type NodeTypeWithLiterals = NodeType | 'PARAGRAPH' | 'TEXT' | 'HEADING' | 'BULLETED_LIST' | 'ORDERED_LIST' | 'LIST_ITEM' | 'BLOCKQUOTE' | 'CODE_BLOCK' | 'VIDEO' | 'DIVIDER' | 'FILE' | 'GALLERY' | 'GIF' | 'HTML' | 'IMAGE' | 'LINK_PREVIEW' | 'MAP' | 'POLL' | 'APP_EMBED' | 'BUTTON' | 'COLLAPSIBLE_LIST' | 'TABLE' | 'EMBED' | 'COLLAPSIBLE_ITEM' | 'COLLAPSIBLE_ITEM_TITLE' | 'COLLAPSIBLE_ITEM_BODY' | 'TABLE_CELL' | 'TABLE_ROW' | 'EXTERNAL' | 'AUDIO' | 'CAPTION' | 'LAYOUT' | 'LAYOUT_CELL';
interface NodeStyle {
    /** The top padding value in pixels. */
    paddingTop?: string | null;
    /** The bottom padding value in pixels. */
    paddingBottom?: string | null;
    /** The background color as a hexadecimal value. */
    backgroundColor?: string | null;
}
interface ButtonData {
    /** Styling for the button's container. */
    containerData?: PluginContainerData;
    /** The button type. */
    type?: ButtonDataTypeWithLiterals;
    /** Styling for the button. */
    styles?: Styles;
    /** The text to display on the button. */
    text?: string | null;
    /** Button link details. */
    link?: V1Link;
}
interface Border {
    /**
     * Deprecated: Use `borderWidth` in `styles` instead.
     * @deprecated
     */
    width?: number | null;
    /**
     * Deprecated: Use `borderRadius` in `styles` instead.
     * @deprecated
     */
    radius?: number | null;
}
interface Colors {
    /**
     * Deprecated: Use `textColor` in `styles` instead.
     * @deprecated
     */
    text?: string | null;
    /**
     * Deprecated: Use `borderColor` in `styles` instead.
     * @deprecated
     */
    border?: string | null;
    /**
     * Deprecated: Use `backgroundColor` in `styles` instead.
     * @deprecated
     */
    background?: string | null;
}
interface PluginContainerData {
    /** The width of the node when it's displayed. */
    width?: PluginContainerDataWidth;
    /** The node's alignment within its container. */
    alignment?: PluginContainerDataAlignmentWithLiterals;
    /** Spoiler cover settings for the node. */
    spoiler?: Spoiler;
    /** The height of the node when it's displayed. */
    height?: Height;
    /** Sets whether text should wrap around this node when it's displayed. If `textWrap` is `false`, the node takes up the width of its container. Defaults to `true` for all node types except 'DIVIVDER' where it defaults to `false`. */
    textWrap?: boolean | null;
}
declare enum WidthType {
    /** Width matches the content width */
    CONTENT = "CONTENT",
    /** Small Width */
    SMALL = "SMALL",
    /** Width will match the original asset width */
    ORIGINAL = "ORIGINAL",
    /** coast-to-coast display */
    FULL_WIDTH = "FULL_WIDTH"
}
/** @enumType */
type WidthTypeWithLiterals = WidthType | 'CONTENT' | 'SMALL' | 'ORIGINAL' | 'FULL_WIDTH';
interface PluginContainerDataWidth extends PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
/** @oneof */
interface PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
declare enum PluginContainerDataAlignment {
    /** Center Alignment */
    CENTER = "CENTER",
    /** Left Alignment */
    LEFT = "LEFT",
    /** Right Alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type PluginContainerDataAlignmentWithLiterals = PluginContainerDataAlignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface Spoiler {
    /** Sets whether the spoiler cover is enabled for this node. Defaults to `false`. */
    enabled?: boolean | null;
    /** The description displayed on top of the spoiler cover. */
    description?: string | null;
    /** The text for the button used to remove the spoiler cover. */
    buttonText?: string | null;
}
interface Height {
    /** A custom height value in pixels. */
    custom?: string | null;
}
declare enum ButtonDataType {
    /** Regular link button */
    LINK = "LINK",
    /** Triggers custom action that is defined in plugin configuration by the consumer */
    ACTION = "ACTION"
}
/** @enumType */
type ButtonDataTypeWithLiterals = ButtonDataType | 'LINK' | 'ACTION';
interface Styles {
    /**
     * Deprecated: Use `borderWidth` and `borderRadius` instead.
     * @deprecated
     */
    border?: Border;
    /**
     * Deprecated: Use `textColor`, `borderColor` and `backgroundColor` instead.
     * @deprecated
     */
    colors?: Colors;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /**
     * Deprecated: Use `borderWidth` for normal/hover states instead.
     * @deprecated
     */
    borderWidthHover?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /**
     * Border color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    borderColorHover?: string | null;
    /**
     * Text color as a hexadecimal value.
     * @format COLOR_HEX
     */
    textColor?: string | null;
    /**
     * Text color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    textColorHover?: string | null;
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Background color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    backgroundColorHover?: string | null;
    /** Button size option, one of `SMALL`, `MEDIUM` or `LARGE`. Defaults to `MEDIUM`. */
    buttonSize?: string | null;
}
interface V1Link extends V1LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
    /**
     * he HTML `target` attribute value for the link. This property defines where the linked document opens as follows:
     * `SELF` - Default. Opens the linked document in the same frame as the link.
     * `BLANK` - Opens the linked document in a new browser tab or window.
     * `PARENT` - Opens the linked document in the link's parent frame.
     * `TOP` - Opens the linked document in the full body of the link's browser tab or window.
     */
    target?: TargetWithLiterals;
    /** The HTML `rel` attribute value for the link. This object specifies the relationship between the current document and the linked document. */
    rel?: Rel;
    /** A serialized object used for a custom or external link panel. */
    customData?: string | null;
}
/** @oneof */
interface V1LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
}
declare enum Target {
    /** Opens the linked document in the same frame as it was clicked (this is default) */
    SELF = "SELF",
    /** Opens the linked document in a new window or tab */
    BLANK = "BLANK",
    /** Opens the linked document in the parent frame */
    PARENT = "PARENT",
    /** Opens the linked document in the full body of the window */
    TOP = "TOP"
}
/** @enumType */
type TargetWithLiterals = Target | 'SELF' | 'BLANK' | 'PARENT' | 'TOP';
interface Rel {
    /** Indicates to search engine crawlers not to follow the link. Defaults to `false`. */
    nofollow?: boolean | null;
    /** Indicates to search engine crawlers that the link is a paid placement such as sponsored content or an advertisement. Defaults to `false`. */
    sponsored?: boolean | null;
    /** Indicates that this link is user-generated content and isn't necessarily trusted or endorsed by the page’s author. For example, a link in a fourm post. Defaults to `false`. */
    ugc?: boolean | null;
    /** Indicates that this link protect referral information from being passed to the target website. */
    noreferrer?: boolean | null;
}
interface CodeBlockData {
    /** Styling for the code block's text. */
    textStyle?: TextStyle;
}
interface TextStyle {
    /** Text alignment. Defaults to `AUTO`. */
    textAlignment?: TextAlignmentWithLiterals;
    /** A CSS `line-height` value for the text expressed as a ratio relative to the font size. For example, if the font size is 20px, a `lineHeight` value of `'1.5'`` results in a line height of 30px. */
    lineHeight?: string | null;
}
declare enum TextAlignment {
    /** browser default, eqivalent to `initial` */
    AUTO = "AUTO",
    /** Left align */
    LEFT = "LEFT",
    /** Right align */
    RIGHT = "RIGHT",
    /** Center align */
    CENTER = "CENTER",
    /** Text is spaced to line up its left and right edges to the left and right edges of the line box, except for the last line */
    JUSTIFY = "JUSTIFY"
}
/** @enumType */
type TextAlignmentWithLiterals = TextAlignment | 'AUTO' | 'LEFT' | 'RIGHT' | 'CENTER' | 'JUSTIFY';
interface DividerData {
    /** Styling for the divider's container. */
    containerData?: PluginContainerData;
    /** Divider line style. */
    lineStyle?: LineStyleWithLiterals;
    /** Divider width. */
    width?: WidthWithLiterals;
    /** Divider alignment. */
    alignment?: AlignmentWithLiterals;
}
declare enum LineStyle {
    /** Single Line */
    SINGLE = "SINGLE",
    /** Double Line */
    DOUBLE = "DOUBLE",
    /** Dashed Line */
    DASHED = "DASHED",
    /** Dotted Line */
    DOTTED = "DOTTED"
}
/** @enumType */
type LineStyleWithLiterals = LineStyle | 'SINGLE' | 'DOUBLE' | 'DASHED' | 'DOTTED';
declare enum Width {
    /** Large line */
    LARGE = "LARGE",
    /** Medium line */
    MEDIUM = "MEDIUM",
    /** Small line */
    SMALL = "SMALL"
}
/** @enumType */
type WidthWithLiterals = Width | 'LARGE' | 'MEDIUM' | 'SMALL';
declare enum Alignment {
    /** Center alignment */
    CENTER = "CENTER",
    /** Left alignment */
    LEFT = "LEFT",
    /** Right alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type AlignmentWithLiterals = Alignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface FileData {
    /** Styling for the file's container. */
    containerData?: PluginContainerData;
    /** The source for the file's data. */
    src?: FileSource;
    /** File name. */
    name?: string | null;
    /** File type. */
    type?: string | null;
    /**
     * Use `sizeInKb` instead.
     * @deprecated
     */
    size?: number | null;
    /** Settings for PDF files. */
    pdfSettings?: PDFSettings;
    /** File MIME type. */
    mimeType?: string | null;
    /** File path. */
    path?: string | null;
    /** File size in KB. */
    sizeInKb?: string | null;
}
declare enum ViewMode {
    /** No PDF view */
    NONE = "NONE",
    /** Full PDF view */
    FULL = "FULL",
    /** Mini PDF view */
    MINI = "MINI"
}
/** @enumType */
type ViewModeWithLiterals = ViewMode | 'NONE' | 'FULL' | 'MINI';
interface FileSource extends FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
    /** Indicates whether the file's source is private. Defaults to `false`. */
    private?: boolean | null;
}
/** @oneof */
interface FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
}
interface PDFSettings {
    /**
     * PDF view mode. One of the following:
     * `NONE` : The PDF isn't displayed.
     * `FULL` : A full page view of the PDF is displayed.
     * `MINI` : A mini view of the PDF is displayed.
     */
    viewMode?: ViewModeWithLiterals;
    /** Sets whether the PDF download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the PDF print button is disabled. Defaults to `false`. */
    disablePrint?: boolean | null;
}
interface GalleryData {
    /** Styling for the gallery's container. */
    containerData?: PluginContainerData;
    /** The items in the gallery. */
    items?: GalleryDataItem[];
    /** Options for defining the gallery's appearance. */
    options?: GalleryOptions;
    /** Sets whether the gallery's expand button is disabled. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Sets whether the gallery's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
}
interface Media {
    /** The source for the media's data. */
    src?: FileSource;
    /** Media width in pixels. */
    width?: number | null;
    /** Media height in pixels. */
    height?: number | null;
    /** Media duration in seconds. Only relevant for audio and video files. */
    duration?: number | null;
}
interface Image {
    /** Image file details. */
    media?: Media;
    /** Link details for images that are links. */
    link?: V1Link;
}
interface Video {
    /** Video file details. */
    media?: Media;
    /** Video thumbnail file details. */
    thumbnail?: Media;
}
interface GalleryDataItem extends GalleryDataItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
    /** Item title. */
    title?: string | null;
    /** Item's alternative text. */
    altText?: string | null;
}
/** @oneof */
interface GalleryDataItemDataOneOf {
    /** An image item. */
    image?: Image;
    /** A video item. */
    video?: Video;
}
interface GalleryOptions {
    /** Gallery layout. */
    layout?: Layout;
    /** Styling for gallery items. */
    item?: ItemStyle;
    /** Styling for gallery thumbnail images. */
    thumbnails?: Thumbnails;
}
declare enum LayoutType {
    /** Collage type */
    COLLAGE = "COLLAGE",
    /** Masonry type */
    MASONRY = "MASONRY",
    /** Grid type */
    GRID = "GRID",
    /** Thumbnail type */
    THUMBNAIL = "THUMBNAIL",
    /** Slider type */
    SLIDER = "SLIDER",
    /** Slideshow type */
    SLIDESHOW = "SLIDESHOW",
    /** Panorama type */
    PANORAMA = "PANORAMA",
    /** Column type */
    COLUMN = "COLUMN",
    /** Magic type */
    MAGIC = "MAGIC",
    /** Fullsize images type */
    FULLSIZE = "FULLSIZE"
}
/** @enumType */
type LayoutTypeWithLiterals = LayoutType | 'COLLAGE' | 'MASONRY' | 'GRID' | 'THUMBNAIL' | 'SLIDER' | 'SLIDESHOW' | 'PANORAMA' | 'COLUMN' | 'MAGIC' | 'FULLSIZE';
declare enum Orientation {
    /** Rows Orientation */
    ROWS = "ROWS",
    /** Columns Orientation */
    COLUMNS = "COLUMNS"
}
/** @enumType */
type OrientationWithLiterals = Orientation | 'ROWS' | 'COLUMNS';
declare enum Crop {
    /** Crop to fill */
    FILL = "FILL",
    /** Crop to fit */
    FIT = "FIT"
}
/** @enumType */
type CropWithLiterals = Crop | 'FILL' | 'FIT';
declare enum ThumbnailsAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Right alignment */
    RIGHT = "RIGHT",
    /** Bottom alignment */
    BOTTOM = "BOTTOM",
    /** Left alignment */
    LEFT = "LEFT",
    /** No thumbnail */
    NONE = "NONE"
}
/** @enumType */
type ThumbnailsAlignmentWithLiterals = ThumbnailsAlignment | 'TOP' | 'RIGHT' | 'BOTTOM' | 'LEFT' | 'NONE';
interface Layout {
    /** Gallery layout type. */
    type?: LayoutTypeWithLiterals;
    /** Sets whether horizontal scroll is enabled. Defaults to `true` unless the layout `type` is set to `GRID` or `COLLAGE`. */
    horizontalScroll?: boolean | null;
    /** Gallery orientation. */
    orientation?: OrientationWithLiterals;
    /** The number of columns to display on full size screens. */
    numberOfColumns?: number | null;
    /** The number of columns to display on mobile screens. */
    mobileNumberOfColumns?: number | null;
}
interface ItemStyle {
    /** Desirable dimension for each item in pixels (behvaior changes according to gallery type) */
    targetSize?: number | null;
    /** Item ratio */
    ratio?: number | null;
    /** Sets how item images are cropped. */
    crop?: CropWithLiterals;
    /** The spacing between items in pixels. */
    spacing?: number | null;
}
interface Thumbnails {
    /** Thumbnail alignment. */
    placement?: ThumbnailsAlignmentWithLiterals;
    /** Spacing between thumbnails in pixels. */
    spacing?: number | null;
}
interface GIFData {
    /** Styling for the GIF's container. */
    containerData?: PluginContainerData;
    /** The source of the full size GIF. */
    original?: GIF;
    /** The source of the downsized GIF. */
    downsized?: GIF;
    /** Height in pixels. */
    height?: number;
    /** Width in pixels. */
    width?: number;
    /** Type of GIF (Sticker or NORMAL). Defaults to `NORMAL`. */
    gifType?: GIFTypeWithLiterals;
}
interface GIF {
    /**
     * GIF format URL.
     * @format WEB_URL
     */
    gif?: string | null;
    /**
     * MP4 format URL.
     * @format WEB_URL
     */
    mp4?: string | null;
    /**
     * Thumbnail URL.
     * @format WEB_URL
     */
    still?: string | null;
}
declare enum GIFType {
    NORMAL = "NORMAL",
    STICKER = "STICKER"
}
/** @enumType */
type GIFTypeWithLiterals = GIFType | 'NORMAL' | 'STICKER';
interface HeadingData {
    /** Heading level from 1-6. */
    level?: number;
    /** Styling for the heading text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
}
interface HTMLData extends HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
    /** Styling for the HTML node's container. Height property is irrelevant for HTML embeds when autoHeight is set to `true`. */
    containerData?: PluginContainerData;
    /** The type of HTML code. */
    source?: SourceWithLiterals;
    /** If container height is aligned with its content height. Defaults to `true`. */
    autoHeight?: boolean | null;
}
/** @oneof */
interface HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
}
declare enum Source {
    HTML = "HTML",
    ADSENSE = "ADSENSE"
}
/** @enumType */
type SourceWithLiterals = Source | 'HTML' | 'ADSENSE';
interface ImageData {
    /** Styling for the image's container. */
    containerData?: PluginContainerData;
    /** Image file details. */
    image?: Media;
    /** Link details for images that are links. */
    link?: V1Link;
    /** Sets whether the image expands to full screen when clicked. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Image's alternative text. */
    altText?: string | null;
    /**
     * Deprecated: use Caption node instead.
     * @deprecated
     */
    caption?: string | null;
    /** Sets whether the image's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the image is decorative and does not need an explanation. Defaults to `false`. */
    decorative?: boolean | null;
    /** Styling for the image. */
    styles?: ImageDataStyles;
}
interface StylesBorder {
    /** Border width in pixels. */
    width?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** Border radius in pixels. */
    radius?: number | null;
}
interface ImageDataStyles {
    /** Border attributes. */
    border?: StylesBorder;
}
interface LinkPreviewData {
    /** Styling for the link preview's container. */
    containerData?: PluginContainerData;
    /** Link details. */
    link?: V1Link;
    /** Preview title. */
    title?: string | null;
    /** Preview thumbnail URL. */
    thumbnailUrl?: string | null;
    /** Preview description. */
    description?: string | null;
    /** The preview content as HTML. */
    html?: string | null;
    /** Styling for the link preview. */
    styles?: LinkPreviewDataStyles;
}
declare enum Position {
    /** Thumbnail positioned at the start (left in LTR layouts, right in RTL layouts) */
    START = "START",
    /** Thumbnail positioned at the end (right in LTR layouts, left in RTL layouts) */
    END = "END",
    /** Thumbnail positioned at the top */
    TOP = "TOP",
    /** Thumbnail hidden and not displayed */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type PositionWithLiterals = Position | 'START' | 'END' | 'TOP' | 'HIDDEN';
interface LinkPreviewDataStyles {
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Title color as a hexadecimal value.
     * @format COLOR_HEX
     */
    titleColor?: string | null;
    /**
     * Subtitle color as a hexadecimal value.
     * @format COLOR_HEX
     */
    subtitleColor?: string | null;
    /**
     * Link color as a hexadecimal value.
     * @format COLOR_HEX
     */
    linkColor?: string | null;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /** Position of thumbnail. Defaults to `START`. */
    thumbnailPosition?: PositionWithLiterals;
}
interface MapData {
    /** Styling for the map's container. */
    containerData?: PluginContainerData;
    /** Map settings. */
    mapSettings?: MapSettings;
}
interface MapSettings {
    /** The address to display on the map. */
    address?: string | null;
    /** Sets whether the map is draggable. */
    draggable?: boolean | null;
    /** Sets whether the location marker is visible. */
    marker?: boolean | null;
    /** Sets whether street view control is enabled. */
    streetViewControl?: boolean | null;
    /** Sets whether zoom control is enabled. */
    zoomControl?: boolean | null;
    /** Location latitude. */
    lat?: number | null;
    /** Location longitude. */
    lng?: number | null;
    /** Location name. */
    locationName?: string | null;
    /** Sets whether view mode control is enabled. */
    viewModeControl?: boolean | null;
    /** Initial zoom value. */
    initialZoom?: number | null;
    /** Map type. `HYBRID` is a combination of the `ROADMAP` and `SATELLITE` map types. */
    mapType?: MapTypeWithLiterals;
}
declare enum MapType {
    /** Roadmap map type */
    ROADMAP = "ROADMAP",
    /** Satellite map type */
    SATELITE = "SATELITE",
    /** Hybrid map type */
    HYBRID = "HYBRID",
    /** Terrain map type */
    TERRAIN = "TERRAIN"
}
/** @enumType */
type MapTypeWithLiterals = MapType | 'ROADMAP' | 'SATELITE' | 'HYBRID' | 'TERRAIN';
interface ParagraphData {
    /** Styling for the paragraph text. */
    textStyle?: TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
    /** Paragraph level */
    level?: number | null;
}
interface PollData {
    /** Styling for the poll's container. */
    containerData?: PluginContainerData;
    /** Poll data. */
    poll?: Poll;
    /** Layout settings for the poll and voting options. */
    layout?: PollDataLayout;
    /** Styling for the poll and voting options. */
    design?: Design;
}
declare enum ViewRole {
    /** Only Poll creator can view the results */
    CREATOR = "CREATOR",
    /** Anyone who voted can see the results */
    VOTERS = "VOTERS",
    /** Anyone can see the results, even if one didn't vote */
    EVERYONE = "EVERYONE"
}
/** @enumType */
type ViewRoleWithLiterals = ViewRole | 'CREATOR' | 'VOTERS' | 'EVERYONE';
declare enum VoteRole {
    /** Logged in member */
    SITE_MEMBERS = "SITE_MEMBERS",
    /** Anyone */
    ALL = "ALL"
}
/** @enumType */
type VoteRoleWithLiterals = VoteRole | 'SITE_MEMBERS' | 'ALL';
interface Permissions {
    /** Sets who can view the poll results. */
    view?: ViewRoleWithLiterals;
    /** Sets who can vote. */
    vote?: VoteRoleWithLiterals;
    /** Sets whether one voter can vote multiple times. Defaults to `false`. */
    allowMultipleVotes?: boolean | null;
}
interface Option {
    /** Option ID. */
    id?: string | null;
    /** Option title. */
    title?: string | null;
    /** The image displayed with the option. */
    image?: Media;
}
interface PollSettings {
    /** Permissions settings for voting. */
    permissions?: Permissions;
    /** Sets whether voters are displayed in the vote results. Defaults to `true`. */
    showVoters?: boolean | null;
    /** Sets whether the vote count is displayed. Defaults to `true`. */
    showVotesCount?: boolean | null;
}
declare enum PollLayoutType {
    /** List */
    LIST = "LIST",
    /** Grid */
    GRID = "GRID"
}
/** @enumType */
type PollLayoutTypeWithLiterals = PollLayoutType | 'LIST' | 'GRID';
declare enum PollLayoutDirection {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type PollLayoutDirectionWithLiterals = PollLayoutDirection | 'LTR' | 'RTL';
interface PollLayout {
    /** The layout for displaying the voting options. */
    type?: PollLayoutTypeWithLiterals;
    /** The direction of the text displayed in the voting options. Text can be displayed either right-to-left or left-to-right. */
    direction?: PollLayoutDirectionWithLiterals;
    /** Sets whether to display the main poll image. Defaults to `false`. */
    enableImage?: boolean | null;
}
interface OptionLayout {
    /** Sets whether to display option images. Defaults to `false`. */
    enableImage?: boolean | null;
}
declare enum BackgroundType {
    /** Color background type */
    COLOR = "COLOR",
    /** Image background type */
    IMAGE = "IMAGE",
    /** Gradiant background type */
    GRADIENT = "GRADIENT"
}
/** @enumType */
type BackgroundTypeWithLiterals = BackgroundType | 'COLOR' | 'IMAGE' | 'GRADIENT';
interface Gradient {
    /** The gradient angle in degrees. */
    angle?: number | null;
    /**
     * The start color as a hexademical value.
     * @format COLOR_HEX
     */
    startColor?: string | null;
    /**
     * The end color as a hexademical value.
     * @format COLOR_HEX
     */
    lastColor?: string | null;
}
interface Background extends BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
    /** Background type. For each option, include the relevant details. */
    type?: BackgroundTypeWithLiterals;
}
/** @oneof */
interface BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
}
interface PollDesign {
    /** Background styling. */
    background?: Background;
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface OptionDesign {
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface Poll {
    /** Poll ID. */
    id?: string | null;
    /** Poll title. */
    title?: string | null;
    /** Poll creator ID. */
    creatorId?: string | null;
    /** Main poll image. */
    image?: Media;
    /** Voting options. */
    options?: Option[];
    /** The poll's permissions and display settings. */
    settings?: PollSettings;
}
interface PollDataLayout {
    /** Poll layout settings. */
    poll?: PollLayout;
    /** Voting otpions layout settings. */
    options?: OptionLayout;
}
interface Design {
    /** Styling for the poll. */
    poll?: PollDesign;
    /** Styling for voting options. */
    options?: OptionDesign;
}
interface TextData {
    /** The text to apply decorations to. */
    text?: string;
    /** The decorations to apply. */
    decorations?: Decoration[];
}
/** Adds appearence changes to text */
interface Decoration extends DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
    /** The type of decoration to apply. */
    type?: DecorationTypeWithLiterals;
}
/** @oneof */
interface DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
}
declare enum DecorationType {
    BOLD = "BOLD",
    ITALIC = "ITALIC",
    UNDERLINE = "UNDERLINE",
    SPOILER = "SPOILER",
    ANCHOR = "ANCHOR",
    MENTION = "MENTION",
    LINK = "LINK",
    COLOR = "COLOR",
    FONT_SIZE = "FONT_SIZE",
    EXTERNAL = "EXTERNAL",
    STRIKETHROUGH = "STRIKETHROUGH"
}
/** @enumType */
type DecorationTypeWithLiterals = DecorationType | 'BOLD' | 'ITALIC' | 'UNDERLINE' | 'SPOILER' | 'ANCHOR' | 'MENTION' | 'LINK' | 'COLOR' | 'FONT_SIZE' | 'EXTERNAL' | 'STRIKETHROUGH';
interface AnchorData {
    /** The target node's ID. */
    anchor?: string;
}
interface ColorData {
    /** The text's background color as a hexadecimal value. */
    background?: string | null;
    /** The text's foreground color as a hexadecimal value. */
    foreground?: string | null;
}
interface LinkData {
    /** Link details. */
    link?: V1Link;
}
interface MentionData {
    /** The mentioned user's name. */
    name?: string;
    /** The version of the user's name that appears after the `@` character in the mention. */
    slug?: string;
    /** Mentioned user's ID. */
    id?: string | null;
}
interface FontSizeData {
    /** The units used for the font size. */
    unit?: FontTypeWithLiterals;
    /** Font size value. */
    value?: number | null;
}
declare enum FontType {
    PX = "PX",
    EM = "EM"
}
/** @enumType */
type FontTypeWithLiterals = FontType | 'PX' | 'EM';
interface SpoilerData {
    /** Spoiler ID. */
    id?: string | null;
}
interface AppEmbedData extends AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
    /** The type of Wix App content being embedded. */
    type?: AppTypeWithLiterals;
    /** The ID of the embedded content. */
    itemId?: string | null;
    /** The name of the embedded content. */
    name?: string | null;
    /**
     * Deprecated: Use `image` instead.
     * @deprecated
     */
    imageSrc?: string | null;
    /** The URL for the embedded content. */
    url?: string | null;
    /** An image for the embedded content. */
    image?: Media;
}
/** @oneof */
interface AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
}
declare enum AppType {
    PRODUCT = "PRODUCT",
    EVENT = "EVENT",
    BOOKING = "BOOKING"
}
/** @enumType */
type AppTypeWithLiterals = AppType | 'PRODUCT' | 'EVENT' | 'BOOKING';
interface BookingData {
    /** Booking duration in minutes. */
    durations?: string | null;
}
interface EventData {
    /** Event schedule. */
    scheduling?: string | null;
    /** Event location. */
    location?: string | null;
}
interface VideoData {
    /** Styling for the video's container. */
    containerData?: PluginContainerData;
    /** Video details. */
    video?: Media;
    /** Video thumbnail details. */
    thumbnail?: Media;
    /** Sets whether the video's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Video title. */
    title?: string | null;
    /** Video options. */
    options?: PlaybackOptions;
}
interface PlaybackOptions {
    /** Sets whether the media will automatically start playing. */
    autoPlay?: boolean | null;
    /** Sets whether media's will be looped. */
    playInLoop?: boolean | null;
    /** Sets whether media's controls will be shown. */
    showControls?: boolean | null;
}
interface EmbedData {
    /** Styling for the oEmbed node's container. */
    containerData?: PluginContainerData;
    /** An [oEmbed](https://www.oembed.com) object. */
    oembed?: Oembed;
    /** Origin asset source. */
    src?: string | null;
}
interface Oembed {
    /** The resource type. */
    type?: string | null;
    /** The width of the resource specified in the `url` property in pixels. */
    width?: number | null;
    /** The height of the resource specified in the `url` property in pixels. */
    height?: number | null;
    /** Resource title. */
    title?: string | null;
    /** The source URL for the resource. */
    url?: string | null;
    /** HTML for embedding a video player. The HTML should have no padding or margins. */
    html?: string | null;
    /** The name of the author or owner of the resource. */
    authorName?: string | null;
    /** The URL for the author or owner of the resource. */
    authorUrl?: string | null;
    /** The name of the resource provider. */
    providerName?: string | null;
    /** The URL for the resource provider. */
    providerUrl?: string | null;
    /** The URL for a thumbnail image for the resource. If this property is defined, `thumbnailWidth` and `thumbnailHeight` must also be defined. */
    thumbnailUrl?: string | null;
    /** The width of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailHeight` must also be defined. */
    thumbnailWidth?: string | null;
    /** The height of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailWidth`must also be defined. */
    thumbnailHeight?: string | null;
    /** The URL for an embedded viedo. */
    videoUrl?: string | null;
    /** The oEmbed version number.  This value must be `1.0`. */
    version?: string | null;
}
interface CollapsibleListData {
    /** Styling for the collapsible list's container. */
    containerData?: PluginContainerData;
    /** If `true`, only one item can be expanded at a time. Defaults to `false`. */
    expandOnlyOne?: boolean | null;
    /** Sets which items are expanded when the page loads. */
    initialExpandedItems?: InitialExpandedItemsWithLiterals;
    /** The direction of the text in the list. Either left-to-right or right-to-left. */
    direction?: DirectionWithLiterals;
    /** If `true`, The collapsible item will appear in search results as an FAQ. */
    isQapageData?: boolean | null;
}
declare enum InitialExpandedItems {
    /** First item will be expended initally */
    FIRST = "FIRST",
    /** All items will expended initally */
    ALL = "ALL",
    /** All items collapsed initally */
    NONE = "NONE"
}
/** @enumType */
type InitialExpandedItemsWithLiterals = InitialExpandedItems | 'FIRST' | 'ALL' | 'NONE';
declare enum Direction {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'LTR' | 'RTL';
interface TableData {
    /** Styling for the table's container. */
    containerData?: PluginContainerData;
    /** The table's dimensions. */
    dimensions?: Dimensions;
    /**
     * Deprecated: Use `rowHeader` and `columnHeader` instead.
     * @deprecated
     */
    header?: boolean | null;
    /** Sets whether the table's first row is a header. Defaults to `false`. */
    rowHeader?: boolean | null;
    /** Sets whether the table's first column is a header. Defaults to `false`. */
    columnHeader?: boolean | null;
}
interface Dimensions {
    /** An array representing relative width of each column in relation to the other columns. */
    colsWidthRatio?: number[];
    /** An array representing the height of each row in pixels. */
    rowsHeight?: number[];
    /** An array representing the minimum width of each column in pixels. */
    colsMinWidth?: number[];
}
interface TableCellData {
    /** Styling for the cell's background color and text alignment. */
    cellStyle?: CellStyle;
    /** The cell's border colors. */
    borderColors?: BorderColors;
}
declare enum VerticalAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Middle alignment */
    MIDDLE = "MIDDLE",
    /** Bottom alignment */
    BOTTOM = "BOTTOM"
}
/** @enumType */
type VerticalAlignmentWithLiterals = VerticalAlignment | 'TOP' | 'MIDDLE' | 'BOTTOM';
interface CellStyle {
    /** Vertical alignment for the cell's text. */
    verticalAlignment?: VerticalAlignmentWithLiterals;
    /**
     * Cell background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
}
interface BorderColors {
    /**
     * Left border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    left?: string | null;
    /**
     * Right border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    right?: string | null;
    /**
     * Top border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    top?: string | null;
    /**
     * Bottom border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    bottom?: string | null;
}
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 * The JSON representation for `NullValue` is JSON `null`.
 */
declare enum NullValue {
    /** Null value. */
    NULL_VALUE = "NULL_VALUE"
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
interface ListValue {
    /** Repeated field of dynamically typed values. */
    values?: any[];
}
interface AudioData {
    /** Styling for the audio node's container. */
    containerData?: PluginContainerData;
    /** Audio file details. */
    audio?: Media;
    /** Sets whether the audio node's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Cover image. */
    coverImage?: Media;
    /** Track name. */
    name?: string | null;
    /** Author name. */
    authorName?: string | null;
    /** An HTML version of the audio node. */
    html?: string | null;
}
interface OrderedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
    /** List start number. */
    start?: number | null;
}
interface BulletedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
}
interface BlockquoteData {
    /** Indentation level from 1-4. */
    indentation?: number;
}
interface CaptionData {
    textStyle?: TextStyle;
}
interface LayoutCellData {
    /** Size of the cell in 12 columns grid. */
    colSpan?: number | null;
}
interface Metadata {
    /** Schema version. */
    version?: number;
    /**
     * When the object was created.
     * @readonly
     * @deprecated
     */
    createdTimestamp?: Date | null;
    /**
     * When the object was most recently updated.
     * @deprecated
     */
    updatedTimestamp?: Date | null;
    /** Object ID. */
    _id?: string | null;
}
interface DocumentStyle {
    /** Styling for H1 nodes. */
    headerOne?: TextNodeStyle;
    /** Styling for H2 nodes. */
    headerTwo?: TextNodeStyle;
    /** Styling for H3 nodes. */
    headerThree?: TextNodeStyle;
    /** Styling for H4 nodes. */
    headerFour?: TextNodeStyle;
    /** Styling for H5 nodes. */
    headerFive?: TextNodeStyle;
    /** Styling for H6 nodes. */
    headerSix?: TextNodeStyle;
    /** Styling for paragraph nodes. */
    paragraph?: TextNodeStyle;
    /** Styling for block quote nodes. */
    blockquote?: TextNodeStyle;
    /** Styling for code block nodes. */
    codeBlock?: TextNodeStyle;
}
interface TextNodeStyle {
    /** The decorations to apply to the node. */
    decorations?: Decoration[];
    /** Padding and background color for the node. */
    nodeStyle?: NodeStyle;
    /** Line height for text in the node. */
    lineHeight?: string | null;
}
interface Badge {
    /** Badge type. */
    type?: TypeWithLiterals;
    /**
     * Badge text.
     * @maxLength 50
     */
    text?: string | null;
}
declare enum Type {
    /** Unknown badge type. */
    UNKNOWN_BADGE_TYPE = "UNKNOWN_BADGE_TYPE",
    /** 1st priority badge type. */
    FIRST_PRIORITY = "FIRST_PRIORITY",
    /** 2nd priority badge type. */
    SECOND_PRIORITY = "SECOND_PRIORITY",
    /** 3rd priority badge type. */
    THIRD_PRIORITY = "THIRD_PRIORITY"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN_BADGE_TYPE' | 'FIRST_PRIORITY' | 'SECOND_PRIORITY' | 'THIRD_PRIORITY';
/** Triggered when an order is confirmed. */
interface OrderConfirmed {
    /** Date and time the order was confirmed. */
    timestamp?: Date | null;
    /**
     * Site language when the order was initiated.
     * @format LANGUAGE
     */
    language?: string | null;
    /** Notifications silenced for this domain event. */
    silent?: boolean | null;
    /**
     * Locale in which the order was created.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /**
     * Event ID to which the order belongs.
     * @format GUID
     */
    eventId?: string;
    /** Unique order number. */
    orderNumber?: string;
    /** Contact ID associated with the order. */
    contactId?: string;
    /**
     * Member ID associated with the order.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Date and time the order was created.
     * @readonly
     */
    created?: Date | null;
    /** Buyer first name. */
    firstName?: string;
    /** Buyer last name. */
    lastName?: string;
    /** Buyer email address. */
    email?: string;
    /** Checkout form response. */
    checkoutForm?: FormResponse;
    /** Order status. */
    status?: OrderStatusWithLiterals;
    /** Payment method used for paid tickets purchase, i.e. "payPal", "creditCard", etc. */
    method?: string | null;
    /** Tickets (generated after payment). */
    tickets?: Ticket[];
    /** Invoice. */
    invoice?: Invoice;
    /** Reservation ID associated with the order. */
    reservationId?: string;
}
interface FormResponse {
    /**
     * Input values entered when filling the form.
     * @maxSize 200
     */
    inputValues?: InputValue[];
}
interface InputValue {
    /**
     * Input field name.
     * @maxLength 100
     */
    inputName?: string;
    /**
     * Text entered into the input field.
     * @maxLength 5000
     */
    value?: string;
    /**
     * Multiple input values. For example, the array is filled if several checkboxes are ticked.
     * @maxSize 100
     * @maxLength 5000
     */
    values?: string[];
}
interface FormattedAddress {
    /**
     * One line address representation.
     * @maxLength 200
     */
    formatted?: string;
    /** Address components (optional). */
    address?: CommonAddress;
}
/** Physical address */
interface CommonAddress extends CommonAddressStreetOneOf {
    /** Street name and number. */
    streetAddress?: CommonStreetAddress;
    /** Main address line, usually street and number as free text. */
    addressLine1?: string | null;
    /**
     * Country code.
     * @format COUNTRY
     */
    country?: string | null;
    /** Subdivision shorthand. Usually, a short code (2 or 3 letters) that represents a state, region, prefecture, or province. e.g. NY */
    subdivision?: string | null;
    /** City name. */
    city?: string | null;
    /** Zip/postal code. */
    postalCode?: string | null;
    /** Free text providing more detailed address info. Usually contains Apt, Suite, and Floor. */
    addressLine2?: string | null;
}
/** @oneof */
interface CommonAddressStreetOneOf {
    /** Street name and number. */
    streetAddress?: CommonStreetAddress;
    /** Main address line, usually street and number as free text. */
    addressLine?: string | null;
}
interface CommonStreetAddress {
    /** Street number. */
    number?: string;
    /** Street name. */
    name?: string;
}
interface CommonAddressLocation {
    /** Address latitude. */
    latitude?: number | null;
    /** Address longitude. */
    longitude?: number | null;
}
interface CommonSubdivision {
    /** Short subdivision code. */
    code?: string;
    /** Subdivision full name. */
    name?: string;
}
/** Subdivision Concordance values */
interface StandardDetails {
    /**
     * subdivision iso-3166-2 code according to [ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2). e.g. US-NY, GB-SCT, NO-30
     * @maxLength 20
     */
    iso31662?: string | null;
}
declare enum OrderStatus {
    /** Order status is not available for this request fieldset. */
    NA_ORDER_STATUS = "NA_ORDER_STATUS",
    /** Order is confirmed, no payment is required. */
    FREE = "FREE",
    /** Order was paid, but the payment gateway suspended the payment. */
    PENDING = "PENDING",
    /** Order is paid. */
    PAID = "PAID",
    /** Order is confirmed but has be paid via offline payment. Status needs to be manually updated to `"PAID"`. */
    OFFLINE_PENDING = "OFFLINE_PENDING",
    /** Order is awaiting for payment at the cashier. */
    INITIATED = "INITIATED",
    /** Order is canceled. */
    CANCELED = "CANCELED",
    /** Order payment is declined. */
    DECLINED = "DECLINED",
    /** Order payment is authorized. */
    AUTHORIZED = "AUTHORIZED",
    /** Order payment is voided. */
    VOIDED = "VOIDED",
    /** Order is partially paid with less than the total amount. */
    PARTIALLY_PAID = "PARTIALLY_PAID"
}
/** @enumType */
type OrderStatusWithLiterals = OrderStatus | 'NA_ORDER_STATUS' | 'FREE' | 'PENDING' | 'PAID' | 'OFFLINE_PENDING' | 'INITIATED' | 'CANCELED' | 'DECLINED' | 'AUTHORIZED' | 'VOIDED' | 'PARTIALLY_PAID';
interface Ticket {
    /** Unique issued ticket number. */
    ticketNumber?: string;
    /**
     * Ticket definition ID.
     * @format GUID
     */
    ticketDefinitionId?: string;
    /** Ticket check-in. */
    checkIn?: CheckIn;
    /** Ticket price. */
    price?: Money;
    /** Whether ticket is archived. */
    archived?: boolean;
    /** Guest first name. */
    firstName?: string | null;
    /** Guest last name. */
    lastName?: string | null;
    /** Guest email. */
    email?: string | null;
    /**
     * Contact ID associated with this ticket.
     * @format GUID
     */
    contactId?: string | null;
    /** Whether ticket is confirmed */
    confirmed?: boolean;
    /**
     * Member ID associated with this ticket.
     * @format GUID
     */
    memberId?: string | null;
    /** Ticket form response (only assigned tickets contain separate forms). */
    form?: FormResponse;
    /** Ticket name. */
    ticketName?: string;
    /** Anonymized tickets no longer contain personally identifiable information (PII). */
    anonymized?: boolean;
    /** URL and password to online conference */
    onlineConferencingLogin?: OnlineConferencingLogin;
    /**
     * Seat ID associated with this ticket.
     * @maxLength 36
     */
    seatId?: string | null;
    /** Whether ticket is canceled. */
    canceled?: boolean | null;
}
interface CheckIn {
    /** Time of check-in. */
    created?: Date | null;
}
interface OnlineConferencingLogin {
    /**
     * Link URL to the online conference.
     * @format WEB_URL
     * @readonly
     */
    link?: string;
    /**
     * Password for the online conference.
     * @readonly
     */
    password?: string | null;
}
interface Invoice {
    items?: Item[];
    /**
     * Total cart amount.
     * @deprecated
     */
    total?: Money;
    /** Discount applied to a cart. */
    discount?: Discount;
    /** Tax applied to a cart. */
    tax?: Tax;
    /** Total cart amount before discount, tax, and fees. */
    subTotal?: Money;
    /**
     * Total amount of a cart after discount, tax, and fees.
     * Grand total is calculated in the following order:
     * 1. Total prices of all items in the cart are calculated.
     * 2. Discount is subtracted from the cart (if applicable).
     * 3. Tax is added (if applicable).
     * 4. Wix ticket service fee is added.
     */
    grandTotal?: Money;
    /**
     * Fees applied to the cart.
     * @readonly
     */
    fees?: Fee[];
    /** Total revenue, excluding fees. (Taxes and payment provider fees are not deducted). */
    revenue?: Money;
    /** Invoice preview URL. Only returned if the order is paid. */
    previewUrl?: string | null;
}
interface Item {
    /**
     * Unique line item ID.
     * @format GUID
     */
    _id?: string;
    /**
     * Line item quantity.
     * @min 1
     * @max 50
     */
    quantity?: number;
    /** Line item name. */
    name?: string;
    /** Line item price. */
    price?: Money;
    /** Total price for line items. Always equal to price * quantity. */
    total?: Money;
    /** Discount applied to the line item. */
    discount?: Discount;
    /** Tax applied to the item. */
    tax?: Tax;
    /**
     * Fees applied to the item.
     * @readonly
     */
    fees?: Fee[];
}
interface Discount {
    /** Total discount amount. */
    amount?: Money;
    /** Total sum after the discount. */
    afterDiscount?: Money;
    /**
     * Discount coupon code.
     * @deprecated
     */
    code?: string;
    /**
     * Discount coupon name.
     * @deprecated
     */
    name?: string;
    /**
     * Discount coupon ID.
     * @deprecated
     */
    couponId?: string;
    /** Discount items. */
    discounts?: DiscountItem[];
}
interface DiscountItem extends DiscountItemDiscountOneOf {
    /** Coupon discount. */
    coupon?: CouponDiscount;
    /** Pricing plan discount. */
    paidPlan?: PaidPlanDiscount;
    /** Total discount amount. */
    amount?: Money;
}
/** @oneof */
interface DiscountItemDiscountOneOf {
    /** Coupon discount. */
    coupon?: CouponDiscount;
    /** Pricing plan discount. */
    paidPlan?: PaidPlanDiscount;
}
interface CouponDiscount {
    /** Discount coupon name. **Deprecated:** Use `invoice.discounts.coupon.name` instead. */
    name?: string;
    /** Discount coupon code. **Deprecated:** Use `invoice.discounts.coupon.code` instead. */
    code?: string;
    /** Discount coupon ID. **Deprecated:** Use `invoice.discounts.coupon.couponId` instead. */
    couponId?: string;
}
interface PaidPlanDiscount extends PaidPlanDiscountDiscountOneOf {
    /** Discount by percentage applied to tickets. */
    percentDiscount?: PercentDiscount;
    /** Name of pricing plan. */
    name?: string;
}
/** @oneof */
interface PaidPlanDiscountDiscountOneOf {
    /** Discount by percentage applied to tickets. */
    percentDiscount?: PercentDiscount;
}
interface PercentDiscount {
    /**
     * Percent rate.
     * @decimalValue options { gte:0.01, lte:100, maxScale:2 }
     */
    rate?: string;
    /** Number of discounted tickets. */
    quantityDiscounted?: number;
}
interface Tax {
    /** Tax type. */
    type?: TaxTypeWithLiterals;
    /**
     * Tax name.
     * @readonly
     */
    name?: string;
    /**
     * Tax rate.
     * @format DECIMAL_VALUE
     */
    rate?: string;
    /** Taxable amount. */
    taxable?: Money;
    /** Total tax amount. */
    amount?: Money;
}
interface Fee {
    /** Fee identifier. */
    name?: FeeNameWithLiterals;
    /** How fee is calculated. */
    type?: FeeTypeWithLiterals;
    /**
     * Fee rate.
     * @format DECIMAL_VALUE
     * @readonly
     */
    rate?: string;
    /** Total amount of fee charges. */
    amount?: Money;
}
declare enum FeeName {
    /** Wix ticket service fee charges applied to the line item. */
    WIX_FEE = "WIX_FEE"
}
/** @enumType */
type FeeNameWithLiterals = FeeName | 'WIX_FEE';
declare enum FeeType {
    /** Fee is added to the ticket price at checkout. */
    FEE_ADDED = "FEE_ADDED",
    /** Seller absorbs the fee. It's deducted from the ticket price. */
    FEE_INCLUDED = "FEE_INCLUDED",
    /** Fee is added to the ticket price at checkout. */
    FEE_ADDED_AT_CHECKOUT = "FEE_ADDED_AT_CHECKOUT"
}
/** @enumType */
type FeeTypeWithLiterals = FeeType | 'FEE_ADDED' | 'FEE_INCLUDED' | 'FEE_ADDED_AT_CHECKOUT';
/** Produced if a buyer email was added to the existing order */
interface OrderEmailAdded {
    /** Order updated timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Site language when Order initiated
     * @format LANGUAGE
     */
    language?: string | null;
    /**
     * Locale in which Order was created.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /** Notifications silenced for this domain event. */
    silent?: boolean | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /**
     * Unique order number.
     * @maxLength 36
     */
    orderNumber?: string;
    /**
     * Contact ID associated with this order.
     * @format GUID
     */
    contactId?: string | null;
    /**
     * Member ID associated with this order.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Order created timestamp.
     * @readonly
     */
    created?: Date | null;
    /**
     * Order updated timestamp.
     * @readonly
     */
    updated?: Date | null;
    /**
     * Buyer first name.
     * @maxLength 255
     */
    firstName?: string | null;
    /**
     * Buyer last name.
     * @maxLength 255
     */
    lastName?: string | null;
    /**
     * Buyer email.
     * @format EMAIL
     */
    email?: string | null;
    /** Checkout form response. */
    checkoutForm?: FormResponse;
    /** Whether order is confirmed - occurs once payment gateway processes the payment and funds reach merchant's account. */
    confirmed?: boolean;
    /** Order status. */
    status?: OrderStatusWithLiterals;
    /**
     * Payment method used for paid tickets purchase, i.e. "payPal", "creditCard", etc.
     * @maxLength 100
     */
    method?: string | null;
    /**
     * Tickets generated after payment.
     * @maxSize 50
     */
    tickets?: Ticket[];
    /** Whether order was archived and excluded from results. */
    archived?: boolean;
    /**
     * Reservation ID associated with this order.
     * @format GUID
     */
    reservationId?: string;
}
interface EventCanceled {
    /** Event canceled timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event title */
    title?: string;
    /**
     * Event creator user ID.
     * @format GUID
     */
    userId?: string | null;
    /** True if at least one guest is registered to the event with any attendance status. */
    hasGuests?: boolean | null;
}
interface EventReminder {
    /** Reminder timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event location. */
    location?: Location;
    /** Event schedule configuration. */
    scheduleConfig?: ScheduleConfig;
    /** Event title. */
    title?: string;
    /**
     * Event creator user ID.
     * @format GUID
     */
    userId?: string | null;
    /** Time until the event starts (currently, reminder is triggered 1 day before event starts). */
    startsIn?: TimeDuration;
    /** True if at least one guest is registered to the event with any attendance status. */
    hasGuests?: boolean | null;
}
/**
 * A coarse-grained representation of time duration divided into whole constituting components of days, hours, and minutes.
 * For example, 25.5 hours duration is represented as `{ days: 1, hours: 1, minutes: 30 }`.
 */
interface TimeDuration {
    /** Number of days. */
    days?: number;
    /**
     * Number of hours.
     * @max 24
     */
    hours?: number;
    /**
     * Number of minutes.
     * @max 60
     */
    minutes?: number;
}
/** Triggered when an order is paid. */
interface OrderPaid {
    /** Date and time the order was paid. */
    timestamp?: Date | null;
    /**
     * Site language when the order was initiated.
     * @format LANGUAGE
     */
    language?: string | null;
    /** Notifications silenced for this domain event. */
    silent?: boolean | null;
    /**
     * Locale in which the order was created.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /**
     * Event ID to which the order belongs.
     * @format GUID
     */
    eventId?: string;
    /** Unique order number. */
    orderNumber?: string;
    /** Reservation ID associated with this order. */
    reservationId?: string;
    /**
     * Contact ID associated with this order.
     * @maxLength 36
     */
    contactId?: string;
    /**
     * Member ID associated with this order.
     * @format GUID
     */
    memberId?: string | null;
    /**
     * Date and time the order was created.
     * @readonly
     */
    created?: Date | null;
    /**
     * Buyer first name.
     * @maxLength 255
     */
    firstName?: string;
    /**
     * Buyer last name.
     * @maxLength 255
     */
    lastName?: string;
    /**
     * Buyer email address.
     * @maxLength 255
     */
    email?: string;
    /** Checkout form response. */
    checkoutForm?: FormResponse;
    /** Order status. */
    status?: OrderStatusWithLiterals;
    /**
     * Payment method used for paid tickets purchase, i.e. "payPal", "creditCard", etc.
     * @maxLength 255
     */
    method?: string | null;
    /**
     * Tickets (generated after payment).
     * @maxSize 50
     */
    tickets?: Ticket[];
    /** Invoice. */
    invoice?: Invoice;
}
interface TicketPdfResolved {
    /**
     * Optional order number
     * @maxLength 36
     */
    orderNumber?: string | null;
    /**
     * Optional ticket number
     * @maxLength 36
     */
    ticketNumber?: string | null;
    /**
     * Resolved download url
     * @format WEB_URL
     */
    downloadUrl?: string | null;
    /** Resolve status */
    resolveFailed?: boolean | null;
    /**
     * Papyrus document id
     * @format GUID
     */
    documentId?: string | null;
}
interface TicketPdfResolveDelayed {
    /**
     * Optional order number
     * @maxLength 36
     */
    orderNumber?: string | null;
    /**
     * Optional ticket number
     * @maxLength 36
     */
    ticketNumber?: string | null;
    /**
     * Papyrus document id
     * @format GUID
     */
    documentId?: string | null;
}
/** Triggered when an order is canceled. */
interface OrderCanceled {
    /**
     * Event ID to which the order belongs.
     * @format GUID
     */
    eventId?: string;
    /**
     * Unique order number.
     * @maxLength 36
     */
    orderNumber?: string;
    /**
     * Reservation ID associated with the order.
     * @format GUID
     */
    reservationId?: string;
    /**
     * Contact ID associated with the order.
     * @maxLength 36
     */
    contactId?: string;
    /**
     * Buyer first name.
     * @maxLength 50
     */
    firstName?: string | null;
    /**
     * Buyer last name.
     * @maxLength 50
     */
    lastName?: string | null;
    /**
     * Buyer email address.
     * @maxLength 255
     */
    email?: string | null;
    /** Checkout form response. */
    checkoutForm?: FormResponse;
    /** Invoice. */
    invoice?: Invoice;
}
interface EventEnded {
    /** Event end timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** True if at least one guest is registered to the event with any attendance status. */
    hasGuests?: boolean | null;
}
interface EventStarted {
    /** Event start timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** True if at least one guest is registered to the event with any attendance status. */
    hasGuests?: boolean | null;
}
interface ResolveNotificationConfigRequest {
    /**
     * Id of the NotificationConfig to retrieve
     * @format GUID
     */
    notificationConfigId: string;
}
interface ResolveNotificationConfigResponse {
    /** The retrieved NotificationConfig */
    notificationConfig?: NotificationConfig;
}
interface UpsertNotificationConfigRequest {
    /** NotificationConfig to be upserted */
    notificationConfig: NotificationConfig;
}
interface UpsertNotificationConfigResponse {
    /** The upserted NotificationConfig */
    notificationConfig?: NotificationConfig;
}
interface ResolveEmailNotificationConfigRequest {
    /**
     * Id of the NotificationConfig to retrieve
     * @format GUID
     */
    notificationConfigId?: string;
    /** Notification type */
    notificationType?: EmailNotificationTypeWithLiterals;
}
interface ResolveEmailNotificationConfigResponse {
    /** The retrieved EmailNotificationConfig */
    emailNotificationConfig?: EmailNotificationConfig;
}
interface EventDeleted {
    /** Event deleted timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event title. */
    title?: string;
    /**
     * Event creator user ID.
     * @format GUID
     */
    userId?: string | null;
}
interface EventCopied {
    /** Event created timestamp in ISO UTC format. */
    timestamp?: Date | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
    /** Event location. */
    location?: Location;
    /** Event schedule configuration. */
    scheduleConfig?: ScheduleConfig;
    /** Event title. */
    title?: string;
    /**
     * Event creator user ID.
     * @format GUID
     */
    userId?: string | null;
    /** Event status. */
    status?: EventStatusWithLiterals;
    /**
     * Instance ID. Indicates the original app instance which current event was derived from.
     * @format GUID
     */
    derivedFromInstanceId?: string | null;
    /**
     * Event ID. Indicates the original event which current event was derived from.
     * @format GUID
     */
    derivedFromEventId?: string | null;
    /**
     * Map of copied ticket definitions from original event.
     * Key represents ticket def id in the original event.
     * Value represents ticket def id in the newly created event.
     */
    ticketDefinitions?: Record<string, string>;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface NotificationConfigCreatedEnvelope {
    entity: NotificationConfig;
    metadata: EventMetadata;
}
interface NotificationConfigUpdatedEnvelope {
    entity: NotificationConfig;
    metadata: EventMetadata;
}
interface TriggerNotificationOptions extends TriggerNotificationOptionsNotificationOneOf, TriggerNotificationOptionsGuestsOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
/** @oneof */
interface TriggerNotificationOptionsNotificationOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
}
/** @oneof */
interface TriggerNotificationOptionsGuestsOneOf {
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
interface UpsertNotificationConfig {
    /**
     * Event ID.
     * @format GUID
     * @immutable
     */
    _id?: string | null;
    /**
     * Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision.
     * @immutable
     */
    revision?: string | null;
    /**
     * Represents the time this NotificationConfig was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Represents the time this NotificationConfig was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /** Rsvp confirmation. */
    rsvpConfirmation?: EmailNotificationConfig;
    /** New spots available. */
    newSpotsAvailable?: EmailNotificationConfig;
    /** Event cancelation. */
    eventCancelation?: EmailNotificationConfig;
    /** Event reminder. */
    upcomingEventReminder?: EmailNotificationConfig;
    /** Order confirmation. */
    orderConfirmation?: EmailNotificationConfig;
    /** Ticket confirmation. */
    ticketConfirmation?: EmailNotificationConfig;
    /** Invoice. */
    invoice?: EmailNotificationConfig;
    /** Order confirmation with tickets link. */
    orderConfirmationWithTicketsLink?: EmailNotificationConfig;
}

export { OrderStatus as $, Alignment as A, ButtonDataType as B, ConferenceType as C, PollLayoutDirection as D, EmailNotificationType as E, BackgroundType as F, GIFType as G, DecorationType as H, InputControlType as I, FontType as J, AppType as K, LocationType as L, MapType as M, type NotificationConfigCreatedEnvelope as N, Orientation as O, PushNotificationType as P, InitialExpandedItems as Q, type ResolveNotificationConfigResponse as R, SubdivisionType as S, type TriggerNotificationOptions as T, type UpsertNotificationConfig as U, VisitorType as V, WidthType as W, Direction as X, VerticalAlignment as Y, NullValue as Z, Type as _, type UpsertNotificationConfigResponse as a, type RsvpSummary as a$, FeeName as a0, FeeType as a1, WebhookIdentityType as a2, type NotificationConfig as a3, type EmailNotificationConfig as a4, type EmailTemplate as a5, type Link as a6, type TriggerNotificationRequest as a7, type TriggerNotificationRequestNotificationOneOf as a8, type TriggerNotificationRequestGuestsOneOf as a9, type Registration as aA, type RsvpCollection as aB, type RsvpCollectionConfig as aC, type Ticketing as aD, type TicketingConfig as aE, type TaxConfig as aF, type Money as aG, type ExternalEvent as aH, type CalendarLinks as aI, type SiteUrl as aJ, type Form as aK, type InputControl as aL, type Input as aM, type OptionSelection as aN, type OptionSelectionSelectedOptionOneOf as aO, type Label as aP, type FormMessages as aQ, type RsvpFormMessages as aR, type PositiveResponseConfirmation as aS, type NegativeResponseConfirmation as aT, type Positive as aU, type Negative as aV, type CheckoutFormMessages as aW, type ResponseConfirmation as aX, type RegistrationClosedMessages as aY, type TicketsUnavailableMessages as aZ, type Dashboard as a_, type RsvpGuest as aa, type OrderGuest as ab, type EventGuests as ac, type TicketGuest as ad, type TriggerNotificationResponse as ae, type DomainEvent as af, type DomainEventBodyOneOf as ag, type EntityCreatedEvent as ah, type RestoreInfo as ai, type EntityUpdatedEvent as aj, type EntityDeletedEvent as ak, type ActionEvent as al, type Empty as am, type EventUpdated as an, type Location as ao, type MapCoordinates as ap, type Address as aq, type AddressStreetOneOf as ar, type StreetAddress as as, type AddressLocation as at, type Subdivision as au, type ScheduleConfig as av, type Recurrences as aw, type Occurrence as ax, type Event as ay, type Scheduling as az, type NotificationConfigUpdatedEnvelope as b, type Permissions as b$, type TicketingSummary as b0, type GuestListConfig as b1, type Feed as b2, type OnlineConferencing as b3, type OnlineConferencingConfig as b4, type OnlineConferencingSession as b5, type SeoSettings as b6, type SeoSchema as b7, type Keyword as b8, type Tag as b9, type FileSource as bA, type FileSourceDataOneOf as bB, type PDFSettings as bC, type GalleryData as bD, type Media as bE, type Image as bF, type Video as bG, type GalleryDataItem as bH, type GalleryDataItemDataOneOf as bI, type GalleryOptions as bJ, type Layout as bK, type ItemStyle as bL, type Thumbnails as bM, type GIFData as bN, type GIF as bO, type HeadingData as bP, type HTMLData as bQ, type HTMLDataDataOneOf as bR, type ImageData as bS, type StylesBorder as bT, type ImageDataStyles as bU, type LinkPreviewData as bV, type LinkPreviewDataStyles as bW, type MapData as bX, type MapSettings as bY, type ParagraphData as bZ, type PollData as b_, type Settings as ba, type Agenda as bb, type Category as bc, type CategoryCounts as bd, type EventDisplaySettings as be, type LabellingSettings as bf, type RichContent as bg, type Node as bh, type NodeDataOneOf as bi, type NodeStyle as bj, type ButtonData as bk, type Border as bl, type Colors as bm, type PluginContainerData as bn, type PluginContainerDataWidth as bo, type PluginContainerDataWidthDataOneOf as bp, type Spoiler as bq, type Height as br, type Styles as bs, type V1Link as bt, type V1LinkDataOneOf as bu, type Rel as bv, type CodeBlockData as bw, type TextStyle as bx, type DividerData as by, type FileData as bz, EmailNotificationReminderTime as c, type DiscountItemDiscountOneOf as c$, type Option as c0, type PollSettings as c1, type PollLayout as c2, type OptionLayout as c3, type Gradient as c4, type Background as c5, type BackgroundBackgroundOneOf as c6, type PollDesign as c7, type OptionDesign as c8, type Poll as c9, type AudioData as cA, type OrderedListData as cB, type BulletedListData as cC, type BlockquoteData as cD, type CaptionData as cE, type LayoutCellData as cF, type Metadata as cG, type DocumentStyle as cH, type TextNodeStyle as cI, type Badge as cJ, type OrderConfirmed as cK, type FormResponse as cL, type InputValue as cM, type FormattedAddress as cN, type CommonAddress as cO, type CommonAddressStreetOneOf as cP, type CommonStreetAddress as cQ, type CommonAddressLocation as cR, type CommonSubdivision as cS, type StandardDetails as cT, type Ticket as cU, type CheckIn as cV, type OnlineConferencingLogin as cW, type Invoice as cX, type Item as cY, type Discount as cZ, type DiscountItem as c_, type PollDataLayout as ca, type Design as cb, type TextData as cc, type Decoration as cd, type DecorationDataOneOf as ce, type AnchorData as cf, type ColorData as cg, type LinkData as ch, type MentionData as ci, type FontSizeData as cj, type SpoilerData as ck, type AppEmbedData as cl, type AppEmbedDataAppDataOneOf as cm, type BookingData as cn, type EventData as co, type VideoData as cp, type PlaybackOptions as cq, type EmbedData as cr, type Oembed as cs, type CollapsibleListData as ct, type TableData as cu, type Dimensions as cv, type TableCellData as cw, type CellStyle as cx, type BorderColors as cy, type ListValue as cz, Status as d, type CouponDiscount as d0, type PaidPlanDiscount as d1, type PaidPlanDiscountDiscountOneOf as d2, type PercentDiscount as d3, type Tax as d4, type Fee as d5, type OrderEmailAdded as d6, type EventCanceled as d7, type EventReminder as d8, type TimeDuration as d9, type OrderPaid as da, type TicketPdfResolved as db, type TicketPdfResolveDelayed as dc, type OrderCanceled as dd, type EventEnded as de, type EventStarted as df, type ResolveNotificationConfigRequest as dg, type UpsertNotificationConfigRequest as dh, type ResolveEmailNotificationConfigRequest as di, type ResolveEmailNotificationConfigResponse as dj, type EventDeleted as dk, type EventCopied as dl, type MessageEnvelope as dm, type IdentificationData as dn, type IdentificationDataIdOneOf as dp, type BaseEventMetadata as dq, type EventMetadata as dr, type TriggerNotificationOptionsNotificationOneOf as ds, type TriggerNotificationOptionsGuestsOneOf as dt, EventStatus as e, EventType as f, RegistrationStatus as g, RsvpStatusOptions as h, TaxType as i, ValueType as j, State as k, NodeType as l, PluginContainerDataAlignment as m, Target as n, TextAlignment as o, LineStyle as p, Width as q, ViewMode as r, LayoutType as s, Crop as t, ThumbnailsAlignment as u, Source as v, Position as w, ViewRole as x, VoteRole as y, PollLayoutType as z };
