// src/events-notifications-v2-notification-config-notifications.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixEventsNotificationsV2NotificationConfigManagementUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/events-notifications",
        destPath: ""
      }
    ],
    _: [
      {
        srcPath: "/_api/events-notifications",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/events-notifications",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/events-notifications",
        destPath: ""
      },
      {
        srcPath: "/events/v2/notifications",
        destPath: "/v2/notifications"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
function resolveWixEventsNotificationsV2NotificationServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/events-notifications",
        destPath: ""
      }
    ],
    _: [
      {
        srcPath: "/_api/events-notifications",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/events-notifications",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/events-notifications",
        destPath: ""
      },
      {
        srcPath: "/events/v2/notifications",
        destPath: "/v2/notifications"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_events_notifications";
function triggerNotification(payload) {
  function __triggerNotification({ host }) {
    const metadata = {
      entityFqdn: "wix.events.notifications.v2.notification_config",
      method: "POST",
      methodFqn: "wix.events.notifications.v2.NotificationService.TriggerNotification",
      packageName: PACKAGE_NAME,
      url: resolveWixEventsNotificationsV2NotificationServiceUrl({
        protoPath: "/v2/notifications/trigger",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __triggerNotification;
}
function resolveNotificationConfig(payload) {
  function __resolveNotificationConfig({ host }) {
    const metadata = {
      entityFqdn: "wix.events.notifications.v2.notification_config",
      method: "GET",
      methodFqn: "wix.events.notifications.v2.NotificationConfigManagement.ResolveNotificationConfig",
      packageName: PACKAGE_NAME,
      url: resolveWixEventsNotificationsV2NotificationConfigManagementUrl({
        protoPath: "/v2/notification-configs/resolve/{notificationConfigId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "notificationConfig.createdDate" },
            { path: "notificationConfig.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __resolveNotificationConfig;
}
function upsertNotificationConfig(payload) {
  function __upsertNotificationConfig({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fieldMask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "notificationConfig.createdDate" },
          { path: "notificationConfig.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.events.notifications.v2.notification_config",
      method: "POST",
      methodFqn: "wix.events.notifications.v2.NotificationConfigManagement.UpsertNotificationConfig",
      packageName: PACKAGE_NAME,
      url: resolveWixEventsNotificationsV2NotificationConfigManagementUrl({
        protoPath: "/v2/notification-configs/{notificationConfig.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "notificationConfig.createdDate" },
            { path: "notificationConfig.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __upsertNotificationConfig;
}

// src/events-notifications-v2-notification-config-notifications.meta.ts
function triggerNotification2() {
  const payload = {};
  const getRequestOptions = triggerNotification(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v2/notifications/trigger",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function resolveNotificationConfig2() {
  const payload = { notificationConfigId: ":notificationConfigId" };
  const getRequestOptions = resolveNotificationConfig(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v2/notification-configs/resolve/{notificationConfigId}",
    pathParams: { notificationConfigId: "notificationConfigId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function upsertNotificationConfig2() {
  const payload = {
    notificationConfig: { id: ":notificationConfigId" }
  };
  const getRequestOptions = upsertNotificationConfig(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v2/notification-configs/{notificationConfig.id}",
    pathParams: { notificationConfigId: "notificationConfigId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  resolveNotificationConfig2 as resolveNotificationConfig,
  triggerNotification2 as triggerNotification,
  upsertNotificationConfig2 as upsertNotificationConfig
};
//# sourceMappingURL=meta.mjs.map