import { a7 as TriggerNotificationRequest$1, ae as TriggerNotificationResponse$1, dg as ResolveNotificationConfigRequest$1, R as ResolveNotificationConfigResponse$1, dh as UpsertNotificationConfigRequest$1, a as UpsertNotificationConfigResponse$1 } from './events-notifications-v2-notification-config-notifications.universal-D-36kOt1.mjs';

interface NotificationConfig {
    /**
     * Event ID.
     * @format GUID
     * @immutable
     */
    id?: string | null;
    /**
     * Represents the current state of an item. Each time the item is modified, its `revision` changes. for an update operation to succeed, you MUST pass the latest revision.
     * @immutable
     */
    revision?: string | null;
    /**
     * Represents the time this NotificationConfig was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Represents the time this NotificationConfig was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Rsvp confirmation. */
    rsvpConfirmation?: EmailNotificationConfig;
    /** New spots available. */
    newSpotsAvailable?: EmailNotificationConfig;
    /** Event cancelation. */
    eventCancelation?: EmailNotificationConfig;
    /** Event reminder. */
    upcomingEventReminder?: EmailNotificationConfig;
    /** Order confirmation. */
    orderConfirmation?: EmailNotificationConfig;
    /** Ticket confirmation. */
    ticketConfirmation?: EmailNotificationConfig;
    /** Invoice. */
    invoice?: EmailNotificationConfig;
    /** Order confirmation with tickets link. */
    orderConfirmationWithTicketsLink?: EmailNotificationConfig;
}
interface EmailNotificationConfig {
    /**
     * Predefined id of the notification type.
     * @readonly
     */
    notificationType?: EmailNotificationTypeWithLiterals;
    /** Email template values. */
    template?: EmailTemplate;
    /**
     * Desired timing of the notification in hours respectfully to event start time.
     * For example if value is 0 then notification is sent at the start of the event.
     */
    reminderTime?: EmailNotificationReminderTimeWithLiterals;
    /** When true the notification will be sent when certain trigger occurs. */
    sendingEnabled?: boolean | null;
}
declare enum EmailNotificationType {
    /** Default value. This value is unused. */
    UNKNOWN_NOTIFICATION_TYPE = "UNKNOWN_NOTIFICATION_TYPE",
    /** Triggered when site user RSVP to the event. */
    EMAIL_RSVP_CONFIRMATION = "EMAIL_RSVP_CONFIRMATION",
    /** Triggered for waiting guests when additional RSVP spots appears in the fully booked event. */
    EMAIL_NEW_SPOTS_AVAILABLE = "EMAIL_NEW_SPOTS_AVAILABLE",
    /** Triggered when event is canceled. */
    EMAIL_EVENT_CANCELATION = "EMAIL_EVENT_CANCELATION",
    /** Triggered before the event start time. */
    EMAIL_UPCOMING_EVENT_REMINDER = "EMAIL_UPCOMING_EVENT_REMINDER",
    /** Triggered when site user creates Order. */
    EMAIL_ORDER_CONFIRMATION = "EMAIL_ORDER_CONFIRMATION",
    /** Triggered when resending ticket to ticket holder. */
    EMAIL_TICKET_CONFIRMATION = "EMAIL_TICKET_CONFIRMATION",
    /** Triggered when sending invoice. Currently only `enabled` flag update is supported. */
    EMAIL_INVOICE = "EMAIL_INVOICE"
}
/** @enumType */
type EmailNotificationTypeWithLiterals = EmailNotificationType | 'UNKNOWN_NOTIFICATION_TYPE' | 'EMAIL_RSVP_CONFIRMATION' | 'EMAIL_NEW_SPOTS_AVAILABLE' | 'EMAIL_EVENT_CANCELATION' | 'EMAIL_UPCOMING_EVENT_REMINDER' | 'EMAIL_ORDER_CONFIRMATION' | 'EMAIL_TICKET_CONFIRMATION' | 'EMAIL_INVOICE';
interface EmailTemplate {
    /**
     * Email subject.
     * @minLength 1
     * @maxLength 100
     */
    subject?: string | null;
    /**
     * Plain text message body.
     * @minLength 1
     * @maxLength 1000
     */
    body?: string | null;
    /** Description link visibility and display text */
    descriptionLink?: Link;
    /** Calendar link visibility and display text */
    calendarLink?: Link;
    /** Online conferencing link visibility and display text */
    onlineConferencingLink?: Link;
    /** When true the tickets are attached to the order confirmation email. */
    includeTickets?: boolean | null;
}
interface Link {
    /** When true the link is added to the email. */
    display?: boolean | null;
    /**
     * Text of the link.
     * @maxLength 60
     */
    linkText?: string | null;
}
declare enum EmailNotificationReminderTime {
    /** Default value. This value is unused. */
    UNKNOWN_REMINDER_TIME = "UNKNOWN_REMINDER_TIME",
    /** Notification is sent instantly */
    INSTANT = "INSTANT",
    /** 24 hours prior */
    BEFORE_1_DAY = "BEFORE_1_DAY",
    /** 3 days prior */
    BEFORE_3_DAYS = "BEFORE_3_DAYS",
    /** 7 days prior */
    BEFORE_1_WEEK = "BEFORE_1_WEEK",
    /** 1 hour prior */
    BEFORE_1_HOUR = "BEFORE_1_HOUR",
    /** 30 minutes prior */
    BEFORE_30_MINUTES = "BEFORE_30_MINUTES"
}
/** @enumType */
type EmailNotificationReminderTimeWithLiterals = EmailNotificationReminderTime | 'UNKNOWN_REMINDER_TIME' | 'INSTANT' | 'BEFORE_1_DAY' | 'BEFORE_3_DAYS' | 'BEFORE_1_WEEK' | 'BEFORE_1_HOUR' | 'BEFORE_30_MINUTES';
interface TriggerNotificationRequest extends TriggerNotificationRequestNotificationOneOf, TriggerNotificationRequestGuestsOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
/** @oneof */
interface TriggerNotificationRequestNotificationOneOf {
    /** Email notification type */
    emailNotificationType?: EmailNotificationTypeWithLiterals;
    /** Push notification type */
    pushNotificationType?: PushNotificationTypeWithLiterals;
}
/** @oneof */
interface TriggerNotificationRequestGuestsOneOf {
    /** Rsvp guest info */
    rsvpGuest?: RsvpGuest;
    /** Order guest info */
    orderGuest?: OrderGuest;
    /** Event guests info */
    eventGuests?: EventGuests;
    /** Ticket guests info */
    ticketGuest?: TicketGuest;
}
declare enum PushNotificationType {
    /** This is default value. This value is unused. */
    UNKNOWN_PUSH_TYPE = "UNKNOWN_PUSH_TYPE",
    /** Triggered when event is updated. */
    PUSH_EVENT_UPDATED = "PUSH_EVENT_UPDATED",
    /** Triggered when event is canceled. */
    PUSH_EVENT_CANCELATION = "PUSH_EVENT_CANCELATION",
    /** Triggered before the event start time. */
    PUSH_UPCOMING_EVENT_REMINDER = "PUSH_UPCOMING_EVENT_REMINDER",
    /** Triggered when event is created. */
    PUSH_EVENT_CREATED = "PUSH_EVENT_CREATED"
}
/** @enumType */
type PushNotificationTypeWithLiterals = PushNotificationType | 'UNKNOWN_PUSH_TYPE' | 'PUSH_EVENT_UPDATED' | 'PUSH_EVENT_CANCELATION' | 'PUSH_UPCOMING_EVENT_REMINDER' | 'PUSH_EVENT_CREATED';
/** Single guest associated to the RSVP */
interface RsvpGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Rsvp id
     * @format GUID
     */
    rsvpId?: string;
}
/** Single guest associated to the Order */
interface OrderGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Order number
     * @maxLength 36
     */
    orderNumber?: string;
}
/** All event guest from RSVPs and Orders */
interface EventGuests {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
}
/** Multiple guests associated to Tickets */
interface TicketGuest {
    /**
     * Event id
     * @format GUID
     */
    eventId?: string;
    /**
     * Order number
     * @maxLength 36
     */
    orderNumber?: string | null;
    /**
     * Ticket numbers must be from the same order only.
     * @minSize 1
     * @maxSize 100
     * @maxLength 36
     */
    ticketNumber?: string[];
}
interface TriggerNotificationResponse {
}
interface ResolveNotificationConfigRequest {
    /**
     * Id of the NotificationConfig to retrieve
     * @format GUID
     */
    notificationConfigId: string;
}
interface ResolveNotificationConfigResponse {
    /** The retrieved NotificationConfig */
    notificationConfig?: NotificationConfig;
}
interface UpsertNotificationConfigRequest {
    /** NotificationConfig to be upserted */
    notificationConfig: NotificationConfig;
}
interface UpsertNotificationConfigResponse {
    /** The upserted NotificationConfig */
    notificationConfig?: NotificationConfig;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function triggerNotification(): __PublicMethodMetaInfo<'POST', {}, TriggerNotificationRequest$1, TriggerNotificationRequest, TriggerNotificationResponse$1, TriggerNotificationResponse>;
declare function resolveNotificationConfig(): __PublicMethodMetaInfo<'GET', {
    notificationConfigId: string;
}, ResolveNotificationConfigRequest$1, ResolveNotificationConfigRequest, ResolveNotificationConfigResponse$1, ResolveNotificationConfigResponse>;
declare function upsertNotificationConfig(): __PublicMethodMetaInfo<'POST', {
    notificationConfigId: string;
}, UpsertNotificationConfigRequest$1, UpsertNotificationConfigRequest, UpsertNotificationConfigResponse$1, UpsertNotificationConfigResponse>;

export { type __PublicMethodMetaInfo, resolveNotificationConfig, triggerNotification, upsertNotificationConfig };
